#
# spec file for package php7
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# these macros are provided by apache-rpm-macros in newer distros
%define apache_apxs       %(ls -1 /usr/{,s}bin/apxs{,2} 2>/dev/null | head -n 1)
%define apache_mmn        %(MMN=$(%{apache_apxs} -q LIBEXECDIR)_MMN; test -x $MMN && $MMN)
%define apache_libexecdir %(%{apache_apxs} -q LIBEXECDIR)
%define apache_sysconfdir %(%{apache_apxs} -q SYSCONFDIR)


# _without_ make_test by default
# use build-test.sh for testing!
%bcond_with make_test

# as soon as suhosin is ported to php7, this with_suhosin and
# related conditions can be removed entirely
%bcond_with suhosin

# firebird first added in 11.2
%if 0%{suse_version} < 1120
%define _without_firebird 1
%endif

# systemd first added in 12.1
%if 0%{suse_version} < 1210
%define _without_systemd 1
%endif

# firebird disabled due to build errors: https://bugs.php.net/bug.php?id=70071
%bcond_without  firebird
%bcond_without  spell
%bcond_without  systemd

%global apiver            20151012
%global zendver           20151012
%define suhosin_version   0.9.38

%define pkg_name          php7
%define extension_dir     %{_libdir}/%{pkg_name}/extensions
%define peardir           %{_datadir}/%{pkg_name}/PEAR
%define php_sysconf       %{_sysconfdir}/%{pkg_name}
%define _x11prefix        %(pkg-config --variable=prefix xft)
%define need_libxml2_hack %(if [ -e %{_includedir}/libxml/parser.h ]; then if grep -q XML_PARSE_OLDSAX %{_includedir}/libxml/parser.h; then echo 1; else echo 0; fi; else echo 0; fi)

Name:           php7
Version:        7.0.7
Release:        40.1
Summary:        PHP7 Core Files
License:        PHP-3.01
Group:          Development/Languages/Other

Url:            http://www.php.net
Source0:        http://us2.php.net/distributions/php-%{version}.tar.xz
Source1:        php-suse-addons.tar.bz2
Source2:        https://download.suhosin.org/suhosin-%{suhosin_version}.tar.gz
Source3:        https://pear.php.net/install-pear-nozlib.phar
Source4:        README.SUSE-pear
Source5:        README.macros
Source6:        macros.php
Source7:        php-fpm.init
Source8:        http://us3.php.net/distributions/php-%{version}.tar.xz.asc
Source9:        php7.keyring
Source10:       README.default_socket_timeout
Source100:      build-test.sh

## SUSE specific patches
Patch0:         php7-phpize.patch
Patch2:         php7-php-config.patch
Patch3:         php7-ini.patch
Patch4:         php7-no-build-date.patch
Patch5:         php7-pts.patch
Patch6:         php7-openssl.patch
Patch7:         php7-systzdata-v13.patch
Patch8:         php7-systemd-unit.patch
Patch9:         php7-depdb-path.patch

## Bugfix patches
Patch10:        php7-mbstring-missing-return.patch
Patch11:        php7-BNC-457056.patch
# following patch is to fix configure tests for crypt; the aim is to have php
# built against glibc's crypt; problem is, that our glibc doesn't support extended
# DES, so as soon as upstream fixes this, don't forgot to remove extended DES
# from their checking as I indicated in crypt-tests.patch yet, or php will
# silently use his own implementation again
Patch12:        php7-crypt-tests.patch
# https://bugs.php.net/bug.php?id=53007
Patch14:        php7-odbc-cmp-int-cast.patch
# https://bugs.php.net/bug.php?id=70461
Patch15:        php7-fix_net-snmp_disable_MD5.patch
# https://bugs.php.net/bug.php?id=70015
Patch16:        aarch64-mult.patch
Patch17:        php-CVE-2016-5772.patch
Patch18:        php-CVE-2016-5770.patch
Patch19:        php-CVE-2016-5769.patch
Patch20:        php-CVE-2016-5766.patch
Patch21:        php-CVE-2016-5773.patch
Patch22:        php-CVE-2016-6128.patch
Patch23:        php-CVE-2016-6161.patch
Patch24:        php-CVE-2016-6292.patch
Patch25:        php-CVE-2016-6295.patch
Patch26:        php-CVE-2016-6297.patch
Patch27:        php-CVE-2016-6291.patch
Patch28:        php-CVE-2016-6289.patch
Patch29:        php-CVE-2016-6290.patch
Patch30:        php-CVE-2016-5399.patch
Patch31:        php-CVE-2016-6296.patch
Patch32:        php-CVE-2016-6207.patch
Patch33:        php-CVE-2016-7131,7132.patch
Patch34:        php-CVE-2016-7129.patch
Patch35:        php-CVE-2016-7133.patch
Patch36:        php-CVE-2016-7130.patch
Patch37:        php-CVE-2016-7134.patch
Patch38:        php-CVE-2016-4473.patch
Patch39:        php-CVE-2016-7128.patch
Patch40:        php-CVE-2016-7127.patch
Patch41:        php-CVE-2016-7126.patch
Patch42:        php-CVE-2016-7125.patch
Patch43:        php-CVE-2016-7124.patch
Patch44:        php-CVE-2016-7412.patch
Patch45:        php-CVE-2016-7417.patch
Patch46:        php-CVE-2016-7413.patch
Patch47:        php-CVE-2016-7418.patch
Patch48:        php-CVE-2016-7414.patch
Patch49:        php-CVE-2016-7416.patch
Patch50:        php-CVE-2016-7568.patch
Patch51:        php-CVE-2016-8670.patch
Patch52:        php-CVE-2016-6911.patch
Patch53:        php-CVE-2016-5385.patch
Patch54:        php-CVE-2016-9137.patch
Patch55:        php-CVE-2016-9933.patch
Patch56:        php-CVE-2016-9934.patch
Patch57:        php-CVE-2016-9935.patch
Patch58:        php-CVE-2016-9936.patch
Patch59:        php-CVE-2016-7480.patch
Patch60:        php-CVE-2017-5340.patch
Patch61:        php-CVE-2016-7478.patch
Patch62:        php-CVE-2016-7479.patch
Patch63:        php-CVE-2016-10161.patch
Patch64:        php-CVE-2016-10162.patch
Patch65:        php-CVE-2016-10158.patch
Patch66:        php-CVE-2016-10167.patch
Patch67:        php-CVE-2016-10168.patch
Patch68:        php-CVE-2016-10166.patch
Patch69:        php-CVE-2016-10159.patch
Patch70:        php-CVE-2016-10160.patch
Patch71:        php-CVE-2015-8994.patch
Patch73:        php-CVE-2017-6441.patch
Patch74:        php-CVE-2016-6294.patch
Patch75:        php-CVE-2017-9227.patch
Patch76:        php-CVE-2017-9226.patch
Patch77:        php-CVE-2017-9224.patch
Patch78:        php-CVE-2017-11142.patch
Patch79:        php-CVE-2017-11145.patch
Patch80:        php-CVE-2017-11146.patch
Patch81:        php-CVE-2016-10397.patch
Patch82:        php-CVE-2017-11147.patch
Patch83:        php-CVE-2017-11144.patch
Patch84:        php7-date-regenerate-lexers.patch
Patch85:        php-CVE-2017-11628.patch
Patch86:        php-CVE-2017-7890.patch
Patch87:        php7-insert-more-derefs.patch
Patch88:        php-CVE-2017-12932.patch
Patch89:        php-CVE-2017-12934.patch
Patch90:        php-CVE-2017-12933.patch
Patch91:        php7-Fix-bug-66773-66862.patch
Patch92:        php7-fix-wrong-reference-serialize.patch
Patch93:        php-CVE-2017-16642.patch
Patch94:        php-CVE-2017-9228.patch
Patch95:        php-CVE-2017-9229.patch
Patch96:        php-CVE-2018-5712.patch
Patch97:        php-CVE-2018-5711.patch
Patch98:        php7-pgsql-memory-leak.patch
Patch99:        php-CVE-2018-7584.patch
Patch100:       php7-splfileobject-escape-character.patch
Patch101:       php-CVE-2018-10545.patch
Patch102:       php-CVE-2018-10547.patch
Patch103:       php-CVE-2018-10546.patch
Patch104:       php-CVE-2018-10548.patch
Patch105:       php-CVE-2018-12882.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  curl
BuildRequires:  curl-devel
BuildRequires:  cyrus-sasl-devel
BuildRequires:  db-devel
BuildRequires:  enchant-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildRequires:  gmp-devel
BuildRequires:  imap-devel
BuildRequires:  krb5-devel
BuildRequires:  libapparmor-devel
BuildRequires:  libbz2-devel
BuildRequires:  libedit-devel
BuildRequires:  libevent-devel
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmcrypt-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  libtidy-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libxslt-devel
BuildRequires:  ncurses-devel
BuildRequires:  net-snmp-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  postfix
BuildRequires:  postgresql-devel
BuildRequires:  re2c
BuildRequires:  sqlite3-devel
BuildRequires:  tcpd-devel
BuildRequires:  unixODBC-devel
BuildRequires:  update-alternatives
BuildRequires:  xz

%if 0%{suse_version} > 1110
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xpm)
%else
BuildRequires:  xorg-x11-devel
%endif

%if 0%{suse_version} > 1110
BuildRequires:  freetds-devel
%endif

%if 0%{suse_version} >= 1320
BuildRequires:  libzip-devel
%endif

%if %{with spell}
BuildRequires:  aspell-devel
%endif

%if %{with firebird}
BuildRequires:  firebird-devel
# libfbclient2-devel pkg split in 12.2
%if 0%{suse_version} > 1210
BuildRequires:  libfbclient2-devel
%endif
%endif

# 10.3 does not install sendmail binary with the minimal system
Requires:       smtp_daemon
Requires:       timezone

# I would like this to become a hard dependency, as PHP is
# documented to have this modules by default (no addtional libs are needed)
Recommends:     php-ctype php-dom php-iconv php-sqlite php-tokenizer
Recommends:     php-xmlreader php-xmlwriter php-json

# other highly reccommended extensions
Suggests:       php-mbstring php-gd php-pear php-gettext php-mysql php-suhosin

## Provides
Provides:       php = %{version}
Provides:       php-api = %{apiver}
Provides:       php-zend-abi = %{zendver}
Provides:       php(api) = %{apiver}
Provides:       php(zend-abi) = %{zendver}

# builtin extensions
Provides:       php-date = %{version}
Provides:       php-filter = %{version}
Provides:       php-hash = %{version}
Provides:       php-pcre = %{version}
Provides:       php-reflection = %{version}
Provides:       php-session = %{version}
Provides:       php-simplexml = %{version}
Provides:       php-spl = %{version}
Provides:       php-xml = %{version}
Provides:       zend = %{zendver}

# conflicts with php5 and should replace it
Conflicts:      php5

%description
This package contains the PHP 7 core files, including PHP binary (CLI)
and PHP configuration (php.ini). This package must be installed in
order to use PHP. Additionally, extension modules and server modules
(e.g. for Apache) may be installed.

Additional documentation is available in package php-doc.


%package devel
Summary:        Include files of PHP7
Group:          Development/Languages/C and C++
# this is required by the installed  development headers
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libxml2-devel
# this is needed for "pecl" functionality
Requires:       autoconf
Requires:       automake
Requires:       libtool
Requires:       pcre-devel
Requires:       php7-pear
Provides:       pecl = %{version}
Provides:       php-devel = %{version}

%description devel
PHP is a server-side, cross-platform, HTML embedded scripting language.
If you are completely new to PHP and want to get some idea of how it
works, have a look at the Introductory Tutorial.  Once you get beyond
that have a look at the example archive sites and some of the other
resources available in the Links section. PHP7 is the latest version.


%package pear
Summary:        PHP Extension and Application Repository
Group:          Development/Libraries/PHP
BuildArch:      noarch
Requires:       %{name}-zlib = %{version}
Requires:       php7-pear-Archive_Tar
Provides:       php-pear = %{version}

%description pear
PEAR is a code repository for PHP extensions and PHP library code
similar to TeX's CTAN and Perl's CPAN. This package provides an access
to the repository.

See http://pear.php.net/manual/ for more details.


%package pear-Archive_Tar
Summary:        Tar file management class
Group:          Productivity/Networking/Web/Servers
BuildArch:      noarch
Requires:       %{name}-pear = %{version}
# php5-pear-Archive_Tar provides Tar.php, which is provided
# by pear package itself; php5-pear-Archive_Tar was dropped
# on version 1.3.10, install-pear-nozlib.phar
# provides 1.4.0 currently
Provides:       php-pear-Archive_Tar = 1.4.0
Provides:       php5-pear-Archive_Tar = 1.4.0
Obsoletes:      php-pear-Archive_Tar < 1.3.11
Obsoletes:      php5-pear-Archive_Tar < 1.3.11

%description pear-Archive_Tar
This class provides handling of tar files in PHP.
It supports creating, listing, extracting and adding to tar files.
Gzip support is available if PHP has the zlib extension built-in orloaded. 
Bz2 compression is also supported with the bz2 extension loaded.


%package -n apache2-mod_php7
Summary:        PHP7 Module for Apache 2.0
Group:          Productivity/Networking/Web/Servers
Requires:       %{apache_mmn}
Requires:       %{name} = %{version}
Requires:       apache2-prefork
PreReq:         apache2
Provides:       mod_php_any = %{version}
Provides:       php-date = %{version}
Provides:       php-filter = %{version}
Provides:       php-pcre = %{version}
Provides:       php-reflection = %{version}
Provides:       php-session = %{version}
Provides:       php-simplexml = %{version}
Provides:       php-spl = %{version}
Provides:       php-xml = %{version}
Supplements:    packageand(%{apache_mmn}:%{name})

%description -n apache2-mod_php7
PHP is a server-side, cross-platform HTML embedded scripting language.
If you are completely new to PHP and want to get some idea of how it
works, have a look at the Introductory tutorial. Once you get beyond
that, have a look at the example archive sites and some of the other
resources available in the links section.

Please refer to /usr/share/doc/packages/php7/README.SUSE for
information on how to load the module into the Apache webserver.


%package fastcgi
Summary:        FastCGI PHP7 Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-cgi = %{version}
Provides:       php-date = %{version}
Provides:       php-fastcgi = %{version}
Provides:       php-filter = %{version}
Provides:       php-pcre = %{version}
Provides:       php-reflection = %{version}
Provides:       php-session = %{version}
Provides:       php-simplexml = %{version}
Provides:       php-spl = %{version}
Provides:       php-xml = %{version}

%description fastcgi
PHP is a server-side, cross-platform HTML embedded scripting language.
If you are completely new to PHP and want to get some idea of how it
works, have a look at the Introductory tutorial. Once you get beyond
that have a look at the example archive sites and some of the other
resources available in the links section.

Please refer to /usr/share/doc/packages/php7/README.FastCGI for
information on how to use this module.


%package fpm
Summary:        FastCGI Process Manager PHP7 Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
PreReq:         %insserv_prereq
Provides:       php-date = %{version}
Provides:       php-filter = %{version}
Provides:       php-fpm = %{version}
Provides:       php-pcre = %{version}
Provides:       php-reflection = %{version}
Provides:       php-session = %{version}
Provides:       php-simplexml = %{version}
Provides:       php-spl = %{version}
Provides:       php-xml = %{version}

%if %{with systemd}
%{systemd_requires}
BuildRequires:  pkgconfig(libsystemd-daemon)
%endif

%description fpm
PHP is a server-side, cross-platform HTML embedded scripting language.
If you are completely new to PHP and want to get some idea of how it
works, have a look at the Introductory tutorial. Once you get beyond
that have a look at the example archive sites and some of the other
resources available in the links section.

Please refer to /usr/share/doc/packages/php7/README.FastCGI for
information on how to use this module.


%package bcmath
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-bcmath = %{version}

%description bcmath
Binary Calculator which supports numbers of any size and precision,
represented as strings.


%package bz2
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-bz2 = %{version}

%description bz2
PHP functions to read and write bzip2 (.bz2) compressed files.


%package calendar
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-calendar = %{version}

%description calendar
PHP functions for converting between different calendar formats.


%package ctype
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-ctype = %{version}

%description ctype
PHP functions for checking whether a character or string falls into a
certain character class according to the current locale.


%package curl
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-curl = %{version}

%description curl
PHP interface to libcurl that allows you to connect to and communicate
with servers of many different types, using protocols of many different
types.


%package dba
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-dba = %{version}

%description dba
This is a general abstraction layer for several file-based databases.
As such, functionality is limited to a common subset of features
supported by modern databases such as Sleepycat Software's DB2. (This
is not to be confused with IBM's DB2 software, which is supported
through the ODBC functions.)


%package dom
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-dom = %{version}

%description dom
This module adds DOM support.


%package enchant
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-enchant = %{version}

%description enchant
Enchant is the PHP binding for the Enchant library. Enchant steps in to provide uniformity and conformity on top of all spelling libraries, and implements certain features that may be lacking in any individual provider library. Everything should "just work" for any and every definition of "just working."


%package exif
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-mbstring = %{version}
Provides:       php-exif = %{version}

%description exif
PHP functions for extracting EXIF (metadata from images) information
stored in headers of JPEG and TIFF images.


%package fileinfo
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-fileinfo = %{version}

%description fileinfo
The functions in this module try to guess the content type and encoding of a file by looking for certain magic byte sequences at specific positions within the file. While this is not a bullet proof approach the heuristics used do a very good job.


%package ftp
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-openssl = %{version}
Provides:       php-ftp = %{version}

%description ftp
PHP functions for access to file servers speaking the File Transfer
Protocol (FTP) as defined in rfc959.


%package gd
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-gd = %{version}

%description gd
PHP functions to create and manipulate image files in a variety of
different image formats, including GIF, PNG, JPEG, WBMP, and XPM. Even
more convenient: PHP can output image streams directly to a browser.


%package gettext
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-gettext = %{version}

%description gettext
PHP functions that implement an NLS (Native Language Support) API which
can be used to internationalize your PHP applications.


%package gmp
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-gmp = %{version}

%description gmp
PHP functions for work with arbitrary-length integers using the GNU MP
library.


%package iconv
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-iconv = %{version}

%description iconv
PHP interface to iconv character set conversion facility.


%package imap
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-imap = %{version}

%description imap
PHP functions in this extension are not limited to the IMAP protocol,
despite their name. The underlying c-client library also supports NNTP,
POP3 and local mailbox access methods.


%package intl
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-intl = %{version}

%description intl
Internationalization extension (further is referred as Intl) is a wrapper for ICU library, enabling PHP programmers to perform UCA-conformant collation and date/time/number/currency formatting in their scripts.


%package json
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-json = %{version}

%description json
Support for JSON (JavaScript Object Notation) serialization.


%package ldap
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-openssl = %{version}
Provides:       php-ldap = %{version}

%description ldap
PHP interface to Lightweight Directory Access Protocol (LDAP).


%package mbstring
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-mbstring = %{version}

%description mbstring
This extension provides multi-byte character safe string functions and
other utility functions such as conversion functions.


%package mcrypt
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-mcrypt = %{version}

%description mcrypt
PHP interface to the mcrypt library, which supports a wide variety of
block algorithms.


%package mysql
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-pdo = %{version}
Provides:       php-mysql = %{version}
Provides:       php_any_db = %{version}

%description mysql
PHP functions for access to MySQL database servers.


%if %{with firebird}
%package firebird
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-pdo = %{version}
Provides:       php-firebird = %{version}
Provides:       php_any_db = %{version}

%description firebird
PHP functions for access to firebird database servers.
%endif

%package odbc
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-pdo = %{version}
Provides:       php-odbc = %{version}
Provides:       php-pdo_odbc = %{version}

%description odbc
This module adds ODBC support.


%package opcache
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-opcache = %{version}

%description opcache
The Zend OPcache provides faster PHP execution through
opcode caching and optimization.


%package openssl
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-openssl = %{version}

%description openssl
This module adds OpenSSL support.


%package pcntl
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-pcntl = %{version}

%description pcntl
This module will attempt to implement all features related to process
spawning and control (fork(), waitpid(), signal(), WIF's, etc). This is
extremley experimental, with hope to become stable on most UNIX's. I
greatly appreciate any feedback, fixes, and or suggestions on how to
improve/better implement this functionality.


%package phar
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-phar = %{version}

%description phar
The phar extension provides a way to put entire PHP applications into a
single file called a "phar" (PHP Archive) for easy distribution and installation.


%package pdo
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-pdo = %{version}

%description pdo
PHP Data Objects - Data Access Abstraction

- light-weight
- provides common API for common database operations
- keeps majority of PHP specific stuff in the PDO core (such as
persistent resource management); drivers should only have to worry
about getting the data and not about PHP internals.


%package pgsql
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-pdo = %{version}
Provides:       php-pgsql = %{version}
Provides:       php_any_db = %{version}

%description pgsql
PHP functions for access to PostgreSQL database servers. It includes
both traditional pgsql and pdo_pgsql drivers.


%package posix
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-posix = %{version}

%description posix
This module allows to use POSIX-like functions in PHP.


%if %{with spell}
%package pspell
Summary:        PHP7 pspell extension
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       aspell-en
Provides:       php-pspell = %{version}

%description pspell
PHP interface to the aspell, which provides spell checking
functionality.
%endif

%package readline
Summary:        PHP7 readline extension
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-readline = %{version}

%description readline
PHP interface to libedit, which provides editable command line as well
as PHP interactive mode (php -a)


%package shmop
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-shmop = %{version}

%description shmop
PHP functions to read, write, create and delete UNIX shared memory
segments.


%package snmp
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-snmp = %{version}

%description snmp
PHP functions for SNMP.


%package soap
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-soap = %{version}

%description soap
This module provides SOAP support.

SOAP extension can be used to write SOAP Servers and Clients. It
supports subsets of SOAP 1.1, SOAP 1.2 and WSDL 1.1 specifications.


%package sockets
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-sockets = %{version}

%description sockets
A low-level interface to the socket communication functions based on
the popular BSD sockets, providing the possibility to act as a socket
server as well as a client. This extension is experimental!


%package sqlite
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-pdo = %{version}
Provides:       php-sqlite = %{version}

%description sqlite
This is an extension for the SQLite Embeddable SQL Database Engine.
http://www.sqlite.org/

SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is the server. The SQLite library reads and writes
directly to and from the database files on disk.

This package includes sqlite and pdo_sqlite modules for sqlite version
2 and 3 respectively.


%if %{with suhosin}
%package suhosin
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-suhosin = %{version}

%description suhosin
Suhosin is an advanced protection system for PHP installations. It was
designed to protect servers and users from known and unknown flaws in
PHP applications and the PHP core.

Suhosin is binary compatible to normal PHP installation, which means it
is compatible to 3rd party binary extension like ZendOptimizer.
%endif

%package sysvmsg
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-sysvmsg = %{version}

%description sysvmsg
This module provides System V IPC support.


%package sysvsem
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-sysvsem = %{version}

%description sysvsem
PHP interface for System V semaphores.


%package sysvshm
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-sysvshm = %{version}

%description sysvshm
PHP interface for System V shared memory.


%package tidy
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-tidy = %{version}

%description tidy
Tidy is an extension based on Libtidy (http://tidy.sf.net/) and allows
a PHP developer to clean, repair, and traverse HTML, XHTML, and XML
documents -- including ones with embedded scripting languages such as
PHP or ASP within them using OO constructs.


%package tokenizer
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-tokenizer = %{version}

%description tokenizer
The tokenizer functions provide an interface to the PHP tokenizer
embedded in the Zend Engine. Using these functions you may write your
own PHP source analyzing or modification tools without having to deal
with the language specification at the lexical level.


%package wddx
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-wddx = %{version}

%description wddx
PHP functions for Web Distributed Data Exchange.


%package xmlrpc
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-xmlrpc = %{version}

%description xmlrpc
This module adds XMLRPC-EPI support.


%package xsl
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-dom = %{version}
Provides:       php-xsl = %{version}

%description xsl
This module adds new XSL support to PHP.


%package xmlreader
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Requires:       %{name}-dom = %{version}
Provides:       php-xmlreader = %{version}

%description xmlreader
XMLReader represents a reader that provides non-cached, forward-only
access to XML data. It is based upon the xmlTextReader API from libxml.


%package xmlwriter
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-xmlwriter = %{version}

%description xmlwriter
XMLWriter wraps the libxml xmlWriter API. Represents a writer that
provides a non-cached, forward-only means of generating streams or
files containing XML data.


%package zip
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-zip = %{version}

%description zip
Zip is an extension to create, modify and read zip files.


%package zlib
Summary:        PHP7 Extension Module
Group:          Development/Libraries/PHP
Requires:       %{name} = %{version}
Provides:       php-zlib = %{version}

%description zlib
PHP functions to read and write gzip (.gz) compressed files.


%prep
echo %{apache_mmn}
%setup -q -n php-%{version} -a 1
%{__tar} xf %{S:2} -C ext
%if %{with suhosin}
%{__mv} ext/suhosin-%{suhosin_version} ext/suhosin
%endif
%{__cp} %{S:3} pear
%{__cp} %{S:4} pear/README.SUSE
%{__cp} %{S:5} .
%{__cp} %{S:10} .

%patch0
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7 -p1
%patch8
%patch10
%if %{need_libxml2_hack}
echo "*** APPLY LIBXML2.7 FIX ***"
%patch11
%else
echo "*** SKIPPING LIBMXL2.7 FIX ***"
%endif
%patch12
%patch14
%patch15
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1
%patch57 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch68 -p1
%patch69 -p1
%patch70 -p1
%patch71 -p1
%patch73 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1
%patch80 -p1
%patch81 -p1
%patch82 -p1
%patch83 -p1
%patch84 -p1
%patch85 -p1
%patch86 -p1
%patch87 -p1
%patch88 -p1
%patch89 -p1
%patch90 -p1
%patch91 -p1
%patch92 -p1
%patch93 -p1
%patch94 -p1
%patch95 -p1
%patch96 -p1
%patch97 -p1
%patch98 -p1
%patch99 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1

# Safety check for API version change.
vapi=`sed -n '/#define PHP_API_VERSION/{s/.* //;p}' main/php.h`
if test "x${vapi}" != "x%{apiver}"; then
    : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
    : Update the apiver macro and rebuild.
    exit 1
fi
vzend=`sed -n '/#define ZEND_MODULE_API_NO/{s/^[^0-9]*//;p;}' Zend/zend_modules.h`
if test "x${vzend}" != "x%{zendver}"; then
    : Error: Upstream Zend ABI version is now ${vzend}, expecting %{zendver}.
    : Update the zendver macro and rebuild.
    exit 1
fi

%build
chmod 644 README.namespaces UPGRADING
# aclocal workaround - to be improved
cat `aclocal --print-ac-dir`/{libtool,ltoptions,ltsugar,ltversion,lt~obsolete}.m4 >>aclocal.m4

# Force use of system libtool:
libtoolize --force --copy
cat `aclocal --print-ac-dir`/{libtool,ltoptions,ltsugar,ltversion,lt~obsolete}.m4 >build/libtool.m4

# Regenerate configure scripts (patches change config.m4's)
touch configure.in
# we build three SAPI
%{__mkdir_p} build-apache2
%{__mkdir_p} build-fpm
%{__mkdir_p} build-fastcgi
%{__mkdir_p} build-cli

%{__rm} -r ext/pcre/pcrelib

# regenerate configure etc.
%{__rm} configure
./buildconf --force

# export flags
CFLAGS="$RPM_OPT_FLAGS -O3 -fPIE -fPIC -DPIC -D_GNU_SOURCE -fno-strict-aliasing"
CXXFLAGS="$RPM_OPT_FLAGS -O3 -fPIE -fPIC -DPIC -D_GNU_SOURCE -fno-strict-aliasing"
%if %{with firebird}
CFLAGS="$CFLAGS -I/usr/include/firebird"
CXXFLAGS="$CXXFLAGS -I/usr/include/firebird"
%endif
export CFLAGS
export CXXFLAGS
export LDFLAGS="-pie"
export NO_INTERACTION=true
# where to install extensions
EXTENSION_DIR=%{extension_dir}
export EXTENSION_DIR
export PHP_MYSQLND_ENABLED=yes
export PHP_MYSQLND_COMPRESSION_SUPPORT=yes
# fix build-cli: libc-client.so needs -lssl
export IMAP_SHARED_LIBADD='-lssl'

# build function
Build()
{
    sapi=$1
    pushd build-$1
    shift
    ../configure \
        --prefix=%{_prefix} \
        --datadir=%{_datadir}/%{pkg_name} \
        --mandir=%{_mandir} \
        --bindir=%{_bindir} \
        --with-libdir=%{_lib} \
        --includedir=%{_includedir} \
        --sysconfdir=%{php_sysconf}/$sapi \
        --with-config-file-path=%{php_sysconf}/$sapi \
        --with-config-file-scan-dir=%{php_sysconf}/conf.d \
        --enable-libxml \
        --enable-session \
%if 0%{?suse_version} > 1010
        --with-pcre-regex=%{_usr} \
%else
        --with-pcre-regex \
%endif
        --enable-xml \
        --enable-simplexml \
        --enable-filter \
        --disable-debug \
        --enable-inline-optimization \
        --disable-rpath \
        --disable-static \
        --enable-shared \
        --with-pic \
        --with-gnu-ld \
        --enable-re2c-cgoto \
        --with-system-tzdata=%{_datadir}/zoneinfo \
        --enable-hash \
        --with-mhash \
        --enable-phpdbg=no \
%if 0%{suse_version} >= 1320
        --with-libzip \
%endif
        "$@" || { cat config.log; exit 1; }
    # Some modules are builtin, reasons:
    #  - libxml can not be shared (and is needed by PEAR)
    #  - spl doesn't build shared
    #  - simplexml is needed by spl
    #  - session need to be builtin, otherwise sqlite and other session engines fail
    #  - pcre is needed for PEAR
    #  - filter is builtin due security reasons
    # We have still have harcoded RPATH in some modules
    %{__sed} -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
    %{__sed} -i 's|^runpath_var=LD_RUN_PATH|runpath_var=LIBTOOL_IS_BROKED|g' libtool
    %{__make} %{?jobs:-j%jobs PHP_PEAR_PHP_BIN=%{_bindir}/php}
    popd
}

# perform all builds
# apache2 sapi
Build apache2 \
    --with-apxs2=%{apache_apxs} \
    --disable-all \
    --disable-cli

# fast-cgi sapi
Build fastcgi \
    --enable-force-cgi-redirect \
    --disable-discard-path \
    --enable-fastcgi \
    --bindir=%{_bindir} \
    --disable-cli \
    --disable-all

Build fpm \
%if %{with systemd}
    --with-fpm-systemd \
%endif
    --enable-fpm \
    --bindir=%{_bindir} \
    --disable-cli \
    --disable-all \
    --localstatedir=/var

Build cli \
    --enable-cli \
    --with-pear=%{peardir} \
    --enable-bcmath=shared \
    --enable-calendar=shared \
    --enable-ctype=shared \
    --enable-dom=shared \
    --enable-exif=shared \
    --enable-ftp=shared \
    --enable-mbstring=shared \
    --enable-mbregex \
    --enable-pcntl=shared \
    --enable-posix=shared \
    --enable-shmop=shared \
    --enable-soap=shared \
    --enable-sockets=shared \
    --enable-sysvmsg=shared \
    --enable-sysvsem=shared \
    --enable-sysvshm=shared \
    --enable-tokenizer=shared \
    --enable-wddx=shared \
    --enable-fileinfo=shared \
    --with-zlib=shared \
    --with-bz2=shared \
    --with-curl=shared \
%if 0%{suse_version} >= 1320
    --with-gd=shared,%{_usr} \
%else
    --with-gd=shared \
%endif
    --enable-gd-native-ttf \
    --with-xpm-dir=%{_x11prefix} \
    --with-freetype-dir=%{_usr} \
    --with-png-dir=%{_usr} \
    --with-jpeg-dir=%{_usr} \
    --with-zlib-dir=%{_usr} \
%if 0%{suse_version} > 1110
    --with-vpx-dir=%{_usr} \
%endif
    --with-gettext=shared \
    --with-gmp=shared \
    --with-iconv=shared \
    --with-imap=shared \
    --with-kerberos \
    --with-imap-ssl \
    --enable-json=shared \
    --with-ldap=shared \
    --with-ldap-sasl=%{_usr} \
    --with-libedit=shared,%{_usr} \
    --with-mcrypt=shared \
    --with-mysql=shared,mysqlnd \
%if %{with firebird}
    --with-interbase=shared \
%endif
%if 0%{?suse_version} > 1110
    --with-mysql-sock=/var/run/mysql/mysql.sock \
%else
    --with-mysql-sock=/var/lib/mysql/mysql.sock \
%endif
    --with-mysqli=shared,mysqlnd \
    --with-unixODBC=shared,%{_usr} \
    --with-openssl=shared \
    --with-pgsql=shared,%{_usr} \
    --enable-phar=shared \
%if %{with spell}
    --with-pspell=shared \
    --with-enchant=shared,%{_usr} \
%endif
    --with-snmp=shared \
    --with-xmlrpc=shared \
    --enable-xmlreader=shared \
    --enable-xmlwriter=shared \
    --with-xsl=shared \
    --with-tidy=shared,%{_usr} \
    --enable-dba=shared \
    --with-db4=%{_usr} \
    --without-gdbm \
    --with-cdb \
    --with-inifile \
    --with-flatfile \
    --enable-pdo=shared \
    --with-pdo_sqlite=shared,%{_usr} \
    --with-sqlite3=shared,%{_usr} \
    --enable-sqlite-utf8 \
    --with-pdo-mysql=shared,mysqlnd \
%if %{with firebird}
    --with-pdo-firebird=shared \
%endif
    --with-pdo-pgsql=shared,%{_usr} \
    --with-pdo-odbc=shared,unixODBC,%{_usr} \
    --enable-zip=shared \
%if %{with suhosin}
    --enable-suhosin=shared \
%endif
    --enable-intl=shared,%{_usr} \
%if 0%{suse_version} > 1110
    --with-mssql=shared,%{_usr} \
%endif
    --disable-cgi


%install
# install function
Install()
{
    pushd build-$1
    %{__make} install INSTALL_ROOT=%{buildroot} PHP_PEAR_PHP_BIN=%{_bindir}/php
    popd
}

# do the actual installation
Install apache2

#need it for yast module
%{__mv} %{buildroot}%{apache_libexecdir}/libphp7.so %{buildroot}%{apache_libexecdir}/mod_php7.so
Install fastcgi
Install cli
Install fpm

# generate php.ini from php.ini-production:
%{__install} -d -m 755 %{buildroot}/%{php_sysconf}/conf.d
%{__install} -d -m 755 %{buildroot}/%{php_sysconf}/apache2
%{__install} -d -m 755 %{buildroot}/%{php_sysconf}/cli
%{__install} -d -m 755 %{buildroot}/%{php_sysconf}/fastcgi
%{__install} -d -m 755 %{buildroot}/%{php_sysconf}/fpm
%{__sed} "s=@extdir@=%{extension_dir}=" php.ini-production \
    > %{buildroot}/%{php_sysconf}/apache2/php.ini
%{__sed} "s=@extdir@=%{extension_dir}=" php.ini-production \
    | %{__sed} -r 's/^(html_errors|implicit_flush|max_execution_time|register_argc_argv)/;\1/' \
    > %{buildroot}/%{php_sysconf}/cli/php.ini
%{__sed} "s=@extdir@=%{extension_dir}=" php.ini-production \
    > %{buildroot}/%{php_sysconf}/fastcgi/php.ini

# prepare configuration files for each extension
extern_modules=""
for f in %{buildroot}%{extension_dir}/*; do
    if test ${f##*.} = a; then
        %{__rm} $f
        continue
    fi
    if test ${f##*.} = so; then
        f=${f%.so}
    fi
    ext=${f##*/}
    extern_modules="$extern_modules $ext"
    echo "; comment out next line to disable $ext extension in php" > %{buildroot}/%{php_sysconf}/conf.d/$ext.ini
    zend_=''
    if [ $ext == "opcache" ]; then
      # http://php.net/manual/en/opcache.installation.php
      zend_='zend_'
    fi
    echo "${zend_}extension=$ext.so" >> %{buildroot}/%{php_sysconf}/conf.d/$ext.ini
done
#suhosin configuration
%if %{with suhosin}
%{__install} -m 644 ext/suhosin/suhosin.ini %{buildroot}/%{php_sysconf}/conf.d/suhosin.ini
%endif
# list of builtin modules
builtin_modules=`./build-cli/sapi/cli/php -m | grep -E -v '^(\[.*)?$' | sort | tr '\n' ' '`
# update readme
%{__sed} "s=@EXTERN_MODULES@=$extern_modules=;s=@BUILTIN_MODULES@=$builtin_modules=" php-suse-addons/README.SUSE > README.SUSE
# apache configuration
%{__mkdir_p} %{buildroot}%{apache_sysconfdir}/conf.d
%{__install} -m 644 php-suse-addons/sysconfig.apache2 %{buildroot}/%{apache_sysconfdir}/conf.d/%{pkg_name}.conf
# directory for sessions
%{__install} -d %{buildroot}/var/lib/%{pkg_name}
# documentation
%{__mv} sapi/cli/README README.CLI
%{__mv} sapi/cgi/README.FastCGI README.FastCGI
%{__rm} -rf %{buildroot}/{.channels,.depdb*,.filemap,.lock,usr/bin/peardev}
%{__install} -d -m 0755 %{buildroot}/%{peardir}/test
# for pear XML files
%{__install} -d -m 0755 %{buildroot}/var/lib/pear
# provide compat symlink
%{__mkdir_p} %{buildroot}/srv/www/cgi-bin
%{__ln_s} /usr/bin/php-cgi %{buildroot}/srv/www/cgi-bin/php
#fix symlink
sed -i -e "s@$RPM_BUILD_DIR/php-%{rversion}/build-cli/sapi/cli/php@php@g" %{buildroot}%{_bindir}/phar.phar
rm %{buildroot}%{_bindir}/phar
%{__ln_s} -f %{_bindir}/phar.phar %{buildroot}%{_bindir}/phar
# CVE-2014-5459, bnc#893849; couldn't find a way to use PHP_PEAR_CACHE_DIR 
# (install-pear is checking if the directory is writable by current user?;
#  unfortunately ENOTIME to figure out)
%{__sed} -i 's@15:"/tmp/pear/cache"@19:"/var/cache/php-pear"@' %{buildroot}%{php_sysconf}/cli/pear.conf
grep -c '/var/cache/php-pear' %{buildroot}%{php_sysconf}/cli/pear.conf || exit 1
# after the update for php 5.6.15 landed in Tumbleweed, almost all PEAR
# packages building against broke. The metadata generated when building
# the PEAR package gets written to /.<meta> instead of
# /usr/share/php7/PEAR/.<meta>, probably caused by the new PEAR option
# "metadata_dir" that was added in PEAR 1.10.0. Our specs suspect the data
# to be in the peardir (where is normally belongs).
# This option is not set in the current php7 package, but maybe providing
# a default value for this would resolve the issue for the +100 packages.
pd=%{peardir}
%{__sed} -i "s@\"metadata_dir\";s:0:\"\"@\"metadata_dir\";s:${#pd}:\"${pd}\"@" %{buildroot}%{php_sysconf}/cli/pear.conf
grep -c "\"metadata_dir\";s:${#pd}:\"${pd}\""  %{buildroot}%{php_sysconf}/cli/pear.conf || exit 1
# Install the macros file:
install -d $RPM_BUILD_ROOT%{_sysconfdir}/rpm
sed -e "s/@PHP_APIVER@/%{apiver}/;s/@PHP_ZENDVER@/%{zendver}/" \
    < $RPM_SOURCE_DIR/macros.php > macros.php
install -m 644 -c macros.php \
           $RPM_BUILD_ROOT%{_sysconfdir}/rpm/macros.php

#install fpm init script.
install -d %{buildroot}%{_sysconfdir}/init.d
install -m 755 -c %{S:7} %{buildroot}%{_sysconfdir}/init.d/php-fpm
%if %{with systemd}
install -D -m 0644 ./build-fpm/sapi/fpm/php-fpm.service %{buildroot}%{_unitdir}/php-fpm.service
%if 0%{suse_version} > 1220
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcphp-fpm
%else
ln -s /sbin/service %{buildroot}%{_sbindir}/rcphp-fpm
%endif
%else
ln -s %{_sysconfdir}/init.d/php-fpm %{buildroot}%{_sbindir}/rcphp-fpm
%endif
# pear installer installs .depdb{,lock} files into %{buildroot}%{peardir}
# along with .lock, .registry when metadata_dir is not set but does not 
# install them if metadata_dir is set; our Horde packages expect them there 
# though, (they rm them without -f) so always install them along
cd %{buildroot}/%{peardir}
patch -p0 < %{PATCH9}

%post -n apache2-mod_php7
#some distro versions does not have this tool.
if [ -x /usr/sbin/a2enmod ]; then
    if a2enmod -q php5 && ! a2enmod -q php7; then
        a2dismod php5
        a2enmod php7
    fi
fi

%preun -n apache2-mod_php7
if [ "$1" = "0" ]; then
    if [ -x /usr/sbin/a2enmod ]; then
        if a2enmod -q php7; then
            a2dismod php7
        fi
    fi
fi

%if %{with systemd}
%pre fpm
%service_add_pre php-fpm.service

%postun fpm
%service_del_postun php-fpm.service
%restart_on_update php-fpm
%insserv_cleanup

%preun fpm
%service_del_preun php-fpm.service
%stop_on_removal php-fpm

%post fpm
%service_add_post php-fpm.service
%{fillup_and_insserv -f php-fpm}
%else
%postun fpm
%restart_on_update php-fpm
%insserv_cleanup

%preun fpm
%stop_on_removal php-fpm

%post fpm
%{fillup_and_insserv -f php-fpm}
%endif

%files
%defattr(-, root, root)
%doc README* CODING_STANDARDS CREDITS EXTENSIONS LICENSE NEWS UPGRADING
%doc php-suse-addons/test.php5
%doc %{_mandir}/man1/*
%dir %{php_sysconf}
%dir %{php_sysconf}/conf.d
%dir %{php_sysconf}/cli
%config(noreplace) %{php_sysconf}/cli/php.ini
%{_bindir}/php
%dir %{_libdir}/%{pkg_name}
%dir %{extension_dir}
%dir %{_datadir}/%{pkg_name}
%attr(0755, wwwrun, root) %dir /var/lib/%{pkg_name}

%files devel
%defattr(-, root, root)
%doc README.macros
%{_includedir}/%{pkg_name}
%{_bindir}/phpize
%{_bindir}/php-config
%{_bindir}/pecl
%{_datadir}/%{pkg_name}/build
%config %{_sysconfdir}/rpm/macros.php

%files pear
%defattr(-, root, root)
%doc pear/README.SUSE
%{_bindir}/pear
%config(noreplace) %{php_sysconf}/cli/pear.conf
%{peardir}
%exclude %{peardir}/Archive/Tar.php
%exclude %{peardir}/doc/Archive_Tar
%dir /var/lib/pear

%files pear-Archive_Tar
%defattr(-, root, root)
%dir %{peardir}/Archive
%{peardir}/Archive/Tar.php
%{peardir}/doc/Archive_Tar

%files fastcgi
%defattr(-, root, root)
%{_bindir}/php-cgi
/srv/www/cgi-bin/php
%dir %{php_sysconf}/fastcgi
%config(noreplace) %{php_sysconf}/fastcgi/php.ini

%files fpm
%defattr(-, root, root)
%{_sbindir}/php-fpm
%dir %{php_sysconf}/fpm
%config %{php_sysconf}/fpm/php-fpm.conf.default
%dir %{php_sysconf}/fpm/php-fpm.d
%config %{php_sysconf}/fpm/php-fpm.d/www.conf.default
%{_mandir}/man8/php-fpm.8.gz
%config /etc/init.d/php-fpm
%{_sbindir}/rcphp-fpm
%dir %{_datadir}/%{pkg_name}/fpm
%{_datadir}/%{pkg_name}/fpm/status.html
%if %{with systemd}
%{_unitdir}/php-fpm.service
%endif

%files -n apache2-mod_php7
%defattr(-,root,root)
%{apache_libexecdir}/mod_php7.so
%dir %{php_sysconf}/apache2
%config(noreplace) %{php_sysconf}/apache2/php.ini
%config(noreplace) %{apache_sysconfdir}/conf.d/%{pkg_name}.conf

%files bcmath
%defattr(644,root,root,755)
%{extension_dir}/bcmath.so
%config(noreplace) %{php_sysconf}/conf.d/bcmath.ini

%files bz2
%defattr(644,root,root,755)
%{extension_dir}/bz2.so
%config(noreplace) %{php_sysconf}/conf.d/bz2.ini

%files calendar
%defattr(644,root,root,755)
%{extension_dir}/calendar.so
%config(noreplace) %{php_sysconf}/conf.d/calendar.ini

%files ctype
%defattr(644,root,root,755)
%{extension_dir}/ctype.so
%config(noreplace) %{php_sysconf}/conf.d/ctype.ini

%files curl
%defattr(644,root,root,755)
%{extension_dir}/curl.so
%config(noreplace) %{php_sysconf}/conf.d/curl.ini

%files dba
%defattr(644,root,root,755)
%{extension_dir}/dba.so
%config(noreplace) %{php_sysconf}/conf.d/dba.ini

%files dom
%defattr(644,root,root,755)
%{extension_dir}/dom.so
%config(noreplace) %{php_sysconf}/conf.d/dom.ini

%files enchant
%defattr(644,root,root,755)
%{extension_dir}/enchant.so
%config(noreplace) %{php_sysconf}/conf.d/enchant.ini

%files exif
%defattr(644,root,root,755)
%{extension_dir}/exif.so
%config(noreplace) %{php_sysconf}/conf.d/exif.ini

%files fileinfo
%defattr(644,root,root,755)
%{extension_dir}/fileinfo.so
%config(noreplace) %{php_sysconf}/conf.d/fileinfo.ini

%files ftp
%defattr(644,root,root,755)
%{extension_dir}/ftp.so
%config(noreplace) %{php_sysconf}/conf.d/ftp.ini

%files gd
%defattr(644,root,root,755)
%{extension_dir}/gd.so
%config(noreplace) %{php_sysconf}/conf.d/gd.ini

%files gettext
%defattr(644,root,root,755)
%{extension_dir}/gettext.so
%config(noreplace) %{php_sysconf}/conf.d/gettext.ini

%files gmp
%defattr(644,root,root,755)
%{extension_dir}/gmp.so
%config(noreplace) %{php_sysconf}/conf.d/gmp.ini

%files iconv
%defattr(644,root,root,755)
%{extension_dir}/iconv.so
%config(noreplace) %{php_sysconf}/conf.d/iconv.ini

%files imap
%defattr(644,root,root,755)
%{extension_dir}/imap.so
%config(noreplace) %{php_sysconf}/conf.d/imap.ini

%files intl
%defattr(644,root,root,755)
%{extension_dir}/intl.so
%config(noreplace) %{php_sysconf}/conf.d/intl.ini

%files json
%defattr(644,root,root,755)
%{extension_dir}/json.so
%config(noreplace) %{php_sysconf}/conf.d/json.ini

%files ldap
%defattr(644,root,root,755)
%{extension_dir}/ldap.so
%config(noreplace) %{php_sysconf}/conf.d/ldap.ini

%files mbstring
%defattr(644,root,root,755)
%{extension_dir}/mbstring.so
%config(noreplace) %{php_sysconf}/conf.d/mbstring.ini

%files mcrypt
%defattr(644,root,root,755)
%{extension_dir}/mcrypt.so
%config(noreplace) %{php_sysconf}/conf.d/mcrypt.ini

%files mysql
%defattr(644,root,root,755)
%{extension_dir}/mysqli.so
%config(noreplace) %{php_sysconf}/conf.d/mysqli.ini
%{extension_dir}/pdo_mysql.so
%config(noreplace) %{php_sysconf}/conf.d/pdo_mysql.ini

%if %{with firebird}
%files firebird
%defattr(644,root,root,755)
%{extension_dir}/interbase.so
%config(noreplace) %{php_sysconf}/conf.d/interbase.ini
%{extension_dir}/pdo_firebird.so
%config(noreplace) %{php_sysconf}/conf.d/pdo_firebird.ini
%endif

%files odbc
%defattr(644,root,root,755)
%{extension_dir}/odbc.so
%config(noreplace) %{php_sysconf}/conf.d/odbc.ini
%{extension_dir}/pdo_odbc.so
%config(noreplace) %{php_sysconf}/conf.d/pdo_odbc.ini

%files opcache
%defattr(644,root,root,755)
%{extension_dir}/opcache.so
%config(noreplace) %{php_sysconf}/conf.d/opcache.ini

%files openssl
%defattr(644,root,root,755)
%{extension_dir}/openssl.so
%config(noreplace) %{php_sysconf}/conf.d/openssl.ini

%files phar
%defattr(644,root,root,755)
%{extension_dir}/phar.so
%config(noreplace) %{php_sysconf}/conf.d/phar.ini
%{_bindir}/phar
%{_bindir}/phar.phar

%files pcntl
%defattr(644,root,root,755)
%{extension_dir}/pcntl.so
%config(noreplace) %{php_sysconf}/conf.d/pcntl.ini

%files pdo
%defattr(644,root,root,755)
%{extension_dir}/pdo.so
%config(noreplace) %{php_sysconf}/conf.d/pdo.ini

%files pgsql
%defattr(644,root,root,755)
%{extension_dir}/pgsql.so
%config(noreplace) %{php_sysconf}/conf.d/pgsql.ini
%{extension_dir}/pdo_pgsql.so
%config(noreplace) %{php_sysconf}/conf.d/pdo_pgsql.ini

%files posix
%defattr(644,root,root,755)
%{extension_dir}/posix.so
%config(noreplace) %{php_sysconf}/conf.d/posix.ini

%if %{with spell}
%files pspell
%defattr(644,root,root,755)
%{extension_dir}/pspell.so
%config(noreplace) %{php_sysconf}/conf.d/pspell.ini
%endif

%files readline
%defattr(644,root,root,755)
%{extension_dir}/readline.so
%config(noreplace) %{php_sysconf}/conf.d/readline.ini

%files shmop
%defattr(644,root,root,755)
%{extension_dir}/shmop.so
%config(noreplace) %{php_sysconf}/conf.d/shmop.ini

%files snmp
%defattr(644,root,root,755)
%{extension_dir}/snmp.so
%config(noreplace) %{php_sysconf}/conf.d/snmp.ini

%files soap
%defattr(644,root,root,755)
%{extension_dir}/soap.so
%config(noreplace) %{php_sysconf}/conf.d/soap.ini

%files sockets
%defattr(644,root,root,755)
%{extension_dir}/sockets.so
%config(noreplace) %{php_sysconf}/conf.d/sockets.ini

%files sqlite
%defattr(644,root,root,755)
%{extension_dir}/pdo_sqlite.so
%config(noreplace) %{php_sysconf}/conf.d/pdo_sqlite.ini
%{extension_dir}/sqlite3.so
%config(noreplace) %{php_sysconf}/conf.d/sqlite3.ini

%if %{with suhosin}
%files suhosin
%defattr(644,root,root,755)
%{extension_dir}/suhosin.so
%config(noreplace) %{php_sysconf}/conf.d/suhosin.ini
%endif

%files sysvmsg
%defattr(644,root,root,755)
%{extension_dir}/sysvmsg.so
%config(noreplace) %{php_sysconf}/conf.d/sysvmsg.ini

%files sysvsem
%defattr(644,root,root,755)
%{extension_dir}/sysvsem.so
%config(noreplace) %{php_sysconf}/conf.d/sysvsem.ini

%files sysvshm
%defattr(644,root,root,755)
%{extension_dir}/sysvshm.so
%config(noreplace) %{php_sysconf}/conf.d/sysvshm.ini

%files tidy
%defattr(644,root,root,755)
%{extension_dir}/tidy.so
%config(noreplace) %{php_sysconf}/conf.d/tidy.ini

%files tokenizer
%defattr(644,root,root,755)
%{extension_dir}/tokenizer.so
%config(noreplace) %{php_sysconf}/conf.d/tokenizer.ini

%files wddx
%defattr(644,root,root,755)
%{extension_dir}/wddx.so
%config(noreplace) %{php_sysconf}/conf.d/wddx.ini

%files xmlrpc
%defattr(644,root,root,755)
%{extension_dir}/xmlrpc.so
%config(noreplace) %{php_sysconf}/conf.d/xmlrpc.ini

%files xmlreader
%defattr(644,root,root,755)
%{extension_dir}/xmlreader.so
%config(noreplace) %{php_sysconf}/conf.d/xmlreader.ini

%files xmlwriter
%defattr(644,root,root,755)
%{extension_dir}/xmlwriter.so
%config(noreplace) %{php_sysconf}/conf.d/xmlwriter.ini

%files xsl
%defattr(644,root,root,755)
%{extension_dir}/xsl.so
%config(noreplace) %{php_sysconf}/conf.d/xsl.ini

%files zip
%defattr(644,root,root,755)
%{extension_dir}/zip.so
%config(noreplace) %{php_sysconf}/conf.d/zip.ini

%files zlib
%defattr(644,root,root,755)
%{extension_dir}/zlib.so
%config(noreplace) %{php_sysconf}/conf.d/zlib.ini

%changelog
* Tue Jun 26 2018 pgajdos@suse.com
- security update
  * CVE-2018-12882 [bsc#1099098]
    + php-CVE-2018-12882.patch
* Wed May  2 2018 pgajdos@suse.com
- security update
  * CVE-2018-10545 [bsc#1091367]
    + php-CVE-2018-10545.patch
  * CVE-2018-10547 [bsc#1091362]
    + php-CVE-2018-10547.patch
  * CVE-2018-10546 [bsc#1091363]
    + php-CVE-2018-10546.patch
  * CVE-2018-10548 [bsc#1091355]
    + php-CVE-2018-10548.patch
* Mon Apr 23 2018 pgajdos@suse.com
- SplFileObject::getCsvControl() returns escape character
  [bsc#1090133]
  + php7-splfileobject-escape-character.patch
* Fri Mar  2 2018 pgajdos@suse.com
- security update:
  * CVE-2018-7584 [bsc#1083639]
    + php-CVE-2018-7584.patch
* Mon Feb 19 2018 pgajdos@suse.com
- fixed memory leak in pgsql extension, php function pg_escape_bytea
  [bsc#1076970]
  + php7-pgsql-memory-leak.patch
* Mon Jan 22 2018 pgajdos@suse.com
- security update:
  * CVE-2018-5712 [bsc#1076220]
    + php-CVE-2018-5712.patch
  * CVE-2018-5711 [bsc#1076391]
    + php-CVE-2018-5711.patch
* Mon Nov 27 2017 pgajdos@suse.com
- security update:
  * CVE-2017-9228 [bsc#1069606]
    + php-CVE-2017-9228.patch
  * CVE-2017-9229 [bsc#1069631]
    + php-CVE-2017-9229.patch
* Mon Nov 20 2017 pgajdos@suse.com
- security update:
  * CVE-2017-16642 [bsc#1067441]
    + php-CVE-2017-16642.patch
* Wed Oct 18 2017 pgajdos@suse.com
- Fix Wrong reference when serialize/unserialize an object
  [bsc#1063815]
  + php7-fix-wrong-reference-serialize.patch
* Mon Sep 11 2017 jcejka@suse.de
- Fix namespace encapsulation of imported classes/functions/constants
  (bsc#1057845)
  + php7-Fix-bug-66773-66862.patch
* Mon Sep  4 2017 pgajdos@suse.com
- php7-devel requires php7-pear [bsc#1057104]
* Mon Sep  4 2017 pgajdos@suse.com
- security update:
  * CVE-2017-12933 [bsc#1054430]
    + php-CVE-2017-12933.patch
* Tue Aug 29 2017 pgajdos@suse.com
- security update:
  * CVE-2017-12932 [bsc#1054432]
    + php-CVE-2017-12932.patch
  * CVE-2017-12934 [bsc#1054408]
    + php-CVE-2017-12934.patch
* Tue Aug 15 2017 jcejka@suse.de
- Soap Request with References (bsc#1053645)
  + php7-insert-more-derefs.patch
* Tue Aug  8 2017 pgajdos@suse.com
- security update:
  * CVE-2017-11628 [bsc#1050726]
    + php-CVE-2017-11628.patch
  * CVE-2017-7890 [bsc#1050241]
    + php-CVE-2017-7890.patch
  * complete fix for CVE-2016-5766 [bsc#986386c#23]
    . amended php-CVE-2016-5766.patch
    . refreshed php-CVE-2016-10168.patch
* Mon Aug  7 2017 jweberhofer@weberhofer.at
- php7-pear should explicitly require php7-pear-Archive_Tar
  otherwise this dependency must be declared in every
  php7-pear-* package explicitly. [bnc#1052389]
* Wed Jul 19 2017 pgajdos@suse.com
- security update:
  * CVE-2017-11142 [bsc#1048100]
    + php-CVE-2017-11142.patch
  * CVE-2017-11145 [bsc#1048112]
    + php-CVE-2017-11145.patch
  * CVE-2017-11146 [bsc#1048111]
    + php-CVE-2017-11146.patch
  * CVE-2016-10397 [bsc#1047454]
    + php-CVE-2016-10397.patch
  * CVE-2017-11147 [bsc#1048094]
    + php-CVE-2017-11147.patch
  * CVE-2017-11144 [bsc#1048096]
    + php-CVE-2017-11144.patch
  * regenerate parse_date.c from parse_date.re
    + php7-date-regenerate-lexers.patch
* Tue Jun 20 2017 pgajdos@suse.com
- fix for CVE-2017-7272 was reverted [bsc#1044976]
* Mon May 29 2017 pgajdos@suse.com
- security update:
  * CVE-2017-9227 [bsc#1040883]
    + php-CVE-2017-9227.patch
  * CVE-2017-9226 [bsc#1040889]
    + php-CVE-2017-9226.patch
  * CVE-2017-9224 [bsc#1040891]
    + php-CVE-2017-9224.patch
* Mon Apr 24 2017 pgajdos@suse.com
- security update:
  * CVE-2016-6294 [bsc#1035111]
    + php-CVE-2016-6294.patch
* Mon Apr 10 2017 pgajdos@suse.com
- security update:
  * CVE-2017-6441 [bsc#1032155]
    + php-CVE-2017-6441.patch
* Mon Apr  3 2017 pgajdos@suse.com
- security update:
  * CVE-2017-7272 [bsc#1031246]
    + php-CVE-2017-7272.patch
* Fri Mar 10 2017 pgajdos@suse.com
- security update:
  * CVE-2015-8994 [bsc#1027210]
    + php-CVE-2015-8994.patch
* Mon Jan 30 2017 pgajdos@suse.com
- security update:
  * CVE-2016-10161 [bsc#1022260]
    + php-CVE-2016-10161.patch
  * CVE-2016-10162 [bsc#1022262]
    + php-CVE-2016-10162.patch
  * CVE-2016-10158 [bsc#1022219]
    + php-CVE-2016-10158.patch
  * CVE-2016-10167 [bsc#1022264]
    + php-CVE-2016-10167.patch
  * CVE-2016-10168 [bsc#1022265]
    + php-CVE-2016-10168.patch
  * CVE-2016-10166 [bsc#1022263]
    + php-CVE-2016-10166.patch
  * CVE-2016-10159 [bsc#1022255]
    + php-CVE-2016-10159.patch
  * CVE-2016-10160 [bsc#1022257]
    + php-CVE-2016-10160.patch
* Mon Jan 16 2017 pgajdos@suse.com
- security update:
  * CVE-2016-7480 [bsc#1019568]
    + php-CVE-2016-7480.patch
  * CVE-2017-5340 [bsc#1019570]
    + php-CVE-2017-5340.patch
  * CVE-2016-7478 [bsc#1019550]
    + php-CVE-2016-7478.patch
  * CVE-2016-7479 [bsc#1019547], CVE-2016-9138 [bsc#1008026]
    + php-CVE-2016-7479.patch
* Wed Dec 14 2016 pgajdos@suse.com
- security update:
  * CVE-2016-9933 [bsc#1015187]
    + php-CVE-2016-9933.patch
  * CVE-2016-9934 [bsc#1015188]
    + php-CVE-2016-9934.patch
  * CVE-2016-9935 [bsc#1015189]
    + php-CVE-2016-9935.patch
  * CVE-2016-9936 [bsc#1015191]
    + php-CVE-2016-9936.patch
* Tue Nov  8 2016 pgajdos@suse.com
- security update:
  * CVE-2016-9137 [bsc#1008029]
    + php-CVE-2016-9137.patch
* Mon Oct 31 2016 pgajdos@suse.com
- security update:
  * CVE-2016-5385 [bsc#988486]
    + php-CVE-2016-5385.patch
* Thu Oct 20 2016 pgajdos@suse.com
- security update:
  * CVE-2016-8670 [bsc#1004924]
    + php-CVE-2016-8670.patch
  * CVE-2016-6911 [bsc#1005274]
    + php-CVE-2016-6911.patch
* Fri Oct 14 2016 pgajdos@suse.com
- security update:
  * CVE-2016-7568 [bsc#1001900]
    + php-CVE-2016-7568.patch
* Fri Sep 30 2016 pgajdos@suse.com
- Conflicts instead of Obsoletes [bsc#1001950], [bsc#999313]
* Wed Sep 21 2016 pgajdos@suse.com
- security update:
  * CVE-2016-7412 [bsc#999680]
    + php-CVE-2016-7412.patch
  * CVE-2016-7417 [bsc#999684]
    + php-CVE-2016-7417.patch
  * CVE-2016-7413 [bsc#999679]
    + php-CVE-2016-7413.patch
  * CVE-2016-7418 [bsc#999819]
    + php-CVE-2016-7418.patch
  * CVE-2016-7414 [bsc#999820]
    + php-CVE-2016-7414.patch
  * CVE-2016-7416 [bsc#999685]
    + php-CVE-2016-7416.patch
* Thu Sep  8 2016 pgajdos@suse.com
- security update:
  * CVE-2016-7132 [bsc#997230], CVE-2016-7131 [bsc#997225]
    + php-CVE-2016-7131,7132.patch
  * CVE-2016-7129 [bsc#997220]
    + php-CVE-2016-7129.patch
  * CVE-2016-7133 [bsc#997247]
    + php-CVE-2016-7133.patch
  * CVE-2016-7130 [bsc#997257]
    + php-CVE-2016-7130.patch
  * CVE-2016-7134 [bsc#997248]
    + php-CVE-2016-7134.patch
  * CVE-2016-4473 [bsc#995512]
    + php-CVE-2016-4473.patch
  * CVE-2016-7128 [bsc#997211]
    + php-CVE-2016-7128.patch
  * CVE-2016-7127 [bsc#997210]
    + php-CVE-2016-7127.patch
  * CVE-2016-7126 [bsc#997208]
    + php-CVE-2016-7126.patch
  * CVE-2016-7125 [bsc#997207]
    + php-CVE-2016-7125.patch
  * CVE-2016-7124 [bsc#997206]
    + php-CVE-2016-7124.patch
* Tue Aug  2 2016 pgajdos@suse.com
- security update:
  * CVE-2016-6128 [bsc#987580]
    + php-CVE-2016-6128.patch
  * CVE-2016-6161 [bsc#988032]
    + php-CVE-2016-6161.patch
  * CVE-2016-6292 [bsc#991422]
    + php-CVE-2016-6292.patch
  * CVE-2016-6295 [bsc#991424]
    + php-CVE-2016-6295.patch
  * CVE-2016-6297 [bsc#991426]
    + php-CVE-2016-6297.patch
  * CVE-2016-6291 [bsc#991427]
    + php-CVE-2016-6291.patch
  * CVE-2016-6289 [bsc#991428]
    + php-CVE-2016-6289.patch
  * CVE-2016-6290 [bsc#991429]
    + php-CVE-2016-6290.patch
  * CVE-2016-5399 [bsc#991430]
    + php-CVE-2016-5399.patch
  * CVE-2016-6296 [bsc#991437]
    + php-CVE-2016-6296.patch
  * CVE-2016-6207 [bsc#991434]
    + php-CVE-2016-6207.patch
* Mon Jun 27 2016 pgajdos@suse.com
- security update:
  * CVE-2016-5772 [bsc#986244]
    + php-CVE-2016-5772.patch
  * CVE-2016-5770 [bsc#986392]
    + php-CVE-2016-5770.patch
  * CVE-2016-5769 [bsc#986388]
    + php-CVE-2016-5769.patch
  * CVE-2016-5766 [bsc#986386]
    + php-CVE-2016-5766.patch
  * CVE-2016-5773 [bsc#986247]
    + php-CVE-2016-5773.patch
* Mon May 30 2016 pgajdos@suse.com
- updated to 7.0.7: This is a security release. Several security
  bugs were fixed in this release.
- our bugzilla e. g. [bsc#982010], [bsc#982009]
* Tue May  3 2016 pgajdos@suse.com
- added to sles12, [fate#320127]
* Thu Apr 28 2016 pgajdos@suse.com
- updated to 7.0.6: This is a security release. Several security
  bugs were fixed in this release.
  * removed upstreamed php7-no-reentrant-crypt.patch
* Mon Apr 25 2016 schwab@linux-m68k.org
- aarch64-mult.patch: fix asm constraints in aarch64 multiply macro
* Thu Apr  7 2016 pgajdos@suse.com
- build for sle12
* Wed Apr  6 2016 pgajdos@suse.com
- correct public key
* Fri Apr  1 2016 pgajdos@suse.com
- updated to 7.0.5
* Tue Mar 29 2016 pgajdos@suse.com
- firebird builds now
* Thu Mar  3 2016 jimmy@boombatower.com
- update to 7.0.4
* Wed Feb 10 2016 pgajdos@suse.com
- updated to 7.0.3
* Thu Feb  4 2016 pgajdos@suse.com
- require postgresql-devel < 9.4 for sle12 to fix build
* Fri Jan 29 2016 pgajdos@suse.com
- more versioned provides
* Fri Jan  8 2016 pgajdos@suse.com
- update to 7.0.2: 31 reported bugs has been fixed, including
  6 security related issues.
* Mon Dec 21 2015 jimmy@boombatower.com
- update to 7.0.1
* Mon Dec 14 2015 pgajdos@suse.com
- php5-pear-Archive_Tar provides 1.4.0
- install .depdb and .depdblock files along metadata
  * php5-depdb-path.patch
- versioned provides in subpackages
* Mon Dec 14 2015 jimmy@boombatower.com
- Provide obsoletes for sub-packages to improve upgrade process.
* Wed Dec  9 2015 jimmy@boombatower.com
- Obsolete php5 since php7 conflicts and should replace.
* Mon Dec  7 2015 pgajdos@suse.com
- marcello at ceschia.de: fix path php-fpm.conf
* Mon Nov 23 2015 pgajdos@suse.com
- set pear's metadata dir to %%{peardir}
* Mon Nov 16 2015 aj@ajaissle.de
- Spec cleanup
  * Split Archive_Tar from -pear sub packge to allow updating this
    part via rpm
  * Added "Provides: php-firebird" to -firebird sub package
  * Added "Provides: mod_php_any" to server api module packages
  - fastcgi and -fpm
* Mon Nov 16 2015 pgajdos@suse.com
- test mod_php with %%apache_test_module_curl
- restart apache during mod_php upgrade
* Tue Sep  8 2015 pgajdos@suse.com
- add php5-fix_net-snmp_disable_MD5.patch [bnc#944302]
* Fri Sep  4 2015 pgajdos@suse.com
- fixed segfault in odbc extension when result set is containing
  NULL (php bugs #52554, #53007) [bnc#935074] (internal)
  + php7-odbc-cmp-int-cast.patch
* Tue Jul 14 2015 pgajdos@suse.com
- updated to 7.0.0
  * see NEWS for changes
  * see UPGRADING for 5.6.x -> 7.0.x transition
- removed unneded or not upstreamed patches for long time:
  * php5-cloexec.patch
  * php5-missing-extdeps.patch
  * php5-format-string-issues.patch
  * php5-per-mod-log.patch
  * php5-apache24-updates.patch
  * php5-crypto-checks.patch
  * php5-systzdata-r12.patch (new: php7-systzdata-v13.patch)
* Mon Jul 13 2015 pgajdos@suse.com
- updated to 5.6.11: Five security-related issues in PHP were fixed
  in this release, including CVE-2015-3152.
* Thu Jun 25 2015 crrodriguez@opensuse.org
- php5-systemd-unit.patch: set Killmode=mixed in order
  to ensure fpm and children forked by script can terminate
  cleanly.
* Wed Jun 24 2015 pgajdos@suse.com
-  mod_php5.so executable
* Thu Jun 18 2015 pgajdos@suse.com
- use apache-rpm-macros
* Thu Jun 18 2015 pgajdos@suse.com
- updated to 5.6.10: Several bugs have been fixed as well as several
  security issues into some bundled libraries (CVE-2015-3414,
  CVE-2015-3415, CVE-2015-3416, CVE-2015-2325 and CVE-2015-2326).
* Fri Jun  5 2015 mrueckert@suse.de
- enable apparmor support: new BR libapparmor-devel
* Mon May 18 2015 pgajdos@suse.com
- update to 5.6.9: Several bugs have been fixed.
- systzdata patch updated to r12
  - php5-systzdata-r10.patch
  + php5-systzdata-r12.patch
* Fri Apr 24 2015 pgajdos@suse.com
- update to 5.6.8: Several bugs have been fixed some of them beeing
  security related, like CVE-2015-1351 and CVE-2015-1352.
- refreshed php5-crypto-checks.patch
* Mon Apr 20 2015 pgajdos@suse.com
- configure php-fpm with --localstatedir=/var [bnc#927147]
* Wed Apr  8 2015 pgajdos@suse.com
- systzdata patch updated to r10
  - php5-systzdata-v7.patch
  + php5-systzdata-r10.patch
* Thu Apr  2 2015 pgajdos@suse.com
- build against system gd and libzip only for 13.2 and above
* Tue Mar 24 2015 pgajdos@suse.com
- update to 5.6.7: Several bugs have been fixed as well as
  CVE-2015-0231, CVE-2015-2305 and CVE-2015-2331.
* Tue Mar 24 2015 pgajdos@suse.com
- build against system gd [bnc#923946]
* Fri Mar 20 2015 pgajdos@suse.com
- build against system libzip [bnc#922894]
* Mon Feb 23 2015 pgajdos@suse.com
- update to 5.6.6: fixes several bugs and addresses CVE-2015-0235
  and CVE-2015-0273.
* Mon Feb  9 2015 pgajdos@suse.com
- added README.default_socket_timeout [bnc#907519]
* Tue Feb  3 2015 pgajdos@suse.com
- fix sle_11_sp3 build
* Mon Jan 26 2015 pgajdos@suse.com
- update to 5.6.5: This release fixes several bugs as well as
  CVE-2015-0231, CVE-2014-9427 and CVE-2015-0232.
- removed patches:
  * php-CVE-2014-9426.patch
  * php-CVE-2014-9427.patch
  * php-CVE-2015-0231.patch
* Wed Jan 21 2015 pgajdos@suse.com
- added php-CVE-2015-0231.patch [bnc#910659]
* Mon Jan  5 2015 pgajdos@suse.com
- added php-CVE-2014-9426.patch [bnc#911663]
- added php-CVE-2014-9427.patch [bnc#911664]
* Fri Dec 19 2014 pgajdos@suse.com
- update to 5.6.4: This release fixes several bugs and one CVE
  related to unserialization.
* Tue Nov 18 2014 pgajdos@suse.com
- update to 5.6.3: This release fixes several bugs and one CVE
  in the fileinfo extension.
* Mon Oct 27 2014 pgajdos@suse.com
- update to 5.6.2: Four security-related bugs were fixed in this
  release, including fixes for CVE-2014-3668, CVE-2014-3669 and
  CVE-2014-3670.
* Tue Oct 14 2014 pgajdos@suse.com
- upgraded to 5.6.1:
  * Several bugs were fixed in this release (including CVE-2014-3622).
* Thu Oct  2 2014 crrodriguez@opensuse.org
- php5-crypto-checks.patch: Fix broken libcrypto checks
  DSA_get_default_method is in -lcrypto not -lssl
- DO not use xorg-x11-devel, just pkgconfig(xpm) and xft
- Support WEBP in the gd extension by buildrequiring libvpx-devel
* Fri Aug 29 2014 pgajdos@suse.com
- fix CVE-2014-5459 [bnc#893849]
* Fri Aug 29 2014 pgajdos@suse.com
- actually, there's no point to install pear from other source
  than from php tarball
  * remove source install-pear-nozlib.phar
* Thu Aug 28 2014 pgajdos@suse.com
- updated PEAR to 1.9.5, bugfix release
  see http://pear.php.net/package/PEAR/download
  for details
* Thu Aug 28 2014 pgajdos@suse.com
- updated to 5.6.0:
  * Most improvements in PHP 5.6.x have no impact on existing code.
    There are a few incompatibilities and new features that should
    be considered:
    http://php.net/manual/en/migration56.php
- removed patches:
  * php5-big-file-upload.patch (upstreamed)
  * php5-suhosin-php55.patch (upstreamed)
- modified patches:
  * php5-openssl.patch (refreshed)
* Tue Aug 26 2014 pgajdos@suse.com
- This release fixes several bugs against PHP 5.5.15 and resolves
  CVE-2014-3538, CVE-2014-3587, CVE-2014-2497, CVE-2014-5120 and
  CVE-2014-3597.
- removed patches:
  * php-CVE-2014-2497.patch
* Tue Jul 29 2014 pgajdos@suse.com
- updated to 5.5.15:
  This release fixes several bugs against PHP 5.5.14.
  The list of changes is recorded in the ChangeLog or
  http://php.net/ChangeLog-5.php#5.5.15.
- removed patches:
  * php-CVE-2014-4670.patch (upstreamed)
  * php-CVE-2014-4698.patch (upstreamed)
* Thu Jul 17 2014 pgajdos@suse.com
- security update:
  * php-CVE-2014-4670.patch [bnc#886059]
  * php-CVE-2014-4698.patch [bnc#886060]
- php-5.5.10-CVE-2014-2497.patch renamed to php-CVE-2014-2497.patch
* Tue Jul  1 2014 pgajdos@suse.com
- updated to 5.5.14: This release fixes several bugs against
  PHP 5.5.13. Also, this release fixes a total of 8 CVEs,
  half of them concerning the FileInfo extension.
- removed php-5.5.13-CVE-2014-4049.patch (upstreamed)
* Tue Jun 17 2014 pgajdos@suse.com
- security update
  * php-5.5.13-CVE-2014-4049.patch [bnc#882992]
* Tue Jun 17 2014 pgajdos@suse.com
- php5-5.5.10-CVE-2014-2497.patch renamed to
  php-5.5.10-CVE-2014-2497.patch to be consistent with other
  product php patches names
* Tue Jun  3 2014 pgajdos@suse.com
- do not package latest_test_results.txt; instead, run build-test.sh
  twice: before and after source changes
* Mon Jun  2 2014 pgajdos@suse.com
- updated to 5.5.13: This release fixes several bugs in PHP 5.5.12,
  and addresses two CVEs in Fileinfo (CVE-2014-0238 and CVE-2014-0237).
* Wed May  7 2014 pgajdos@suse.com
- updated to 5.5.12: Fixed several bugs against PHP 5.5.11,
  as well as CVE-2014-0185 regarding PHP-FPM.
- improved build-test.sh
* Wed Apr 30 2014 pgajdos@suse.com
- build-test.sh: use relevant api for build; propagate build
  parameters to osc
* Wed Apr 30 2014 schwab@linux-m68k.org
- php5-gcc_builtins.patch: remove unused patch
* Tue Apr 29 2014 pgajdos@suse.com
- add build-test.sh and latest_test_results.txt for testing
  regressions in tests before and after update. Run
  sh build-test.sh
  after changes. php will get built and test results will be
  compared with latest_test_results.txt and differences reported.
  mv latest_test_results.txt.new latest_test_results.txt
  if differences are acceptable.
* Wed Apr  9 2014 pgajdos@suse.com
- updated to 5.5.11:
  * Several bugs were fixed in this release, some bundled libraries
    updated and a security issue has been fixed : CVE-2013-7345.
* Fri Apr  4 2014 pgajdos@suse.com
- fixed CVE-2014-2497 [bnc#868624]
* Mon Mar 17 2014 pgajdos@suse.com
- updated to 5.5.10:
  * Several bugs were fixed in this release, including security
    issues related to CVEs. CVE-2014-1943, CVE-2014-2270 and
    CVE-2013-7327 have been addressed in this release.
* Tue Feb 11 2014 adaugherity@tamu.edu
- Fix build on non-systemd distros (esp. SLES 11)
* Fri Feb  7 2014 pgajdos@suse.com
- updated to 5.5.9:
  * This release fixes several bugs against PHP 5.5.8.
  * see NEWS or http://www.php.net/ChangeLog-5.php#5.5.9 for
    details
- modified patches:
  * php5-no-build-date.patch (refreshed using quilt)
* Mon Jan 13 2014 pgajdos@suse.com
- updated to 5.5.8:
  * fixes CVE-2013-6712 and build against freetype2
  * see http://www.php.net/ChangeLog-5.php#5.5.8
    for more
  * removed CVE-2013-6712.patch
  * removed freetype2_include_dir.patch
* Fri Dec 20 2013 hrvoje.senjan@gmail.com
- Added php5-freetype2_include_dir.patch: Fixes check of freetype2
  headers, as freetype2 2.5.1 changed the header location
* Wed Dec 18 2013 pgajdos@suse.com
- updated to 5.5.7:
  * fixes some bugs against PHP 5.5.6 and it also includes a fix
    for CVE-2013-6420 in OpenSSL extension
  - > removed CVE-2013-6420.patch
* Wed Dec 11 2013 pgajdos@suse.com
- security update [bnc#854880]
  * added CVE-2013-6420.patch
* Tue Dec  3 2013 pgajdos@suse.com
- security update [bnc#853045]
  * added CVE-2013-6712.patch
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.6:
  * fixes some bugs against PHP 5.5.5, and adds some performance
    improvements.
  * see http://www.php.net/ChangeLog-5.php#5.5.6 for details
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.5:
  * This release fixes about twenty bugs against PHP 5.5.4, some
    of them regarding the build system.
  * added sys_temp_dir ini directive
- removed custom-tmp-dir.patch (upstreamed)
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.4:
  * This release fixes several bugs against PHP 5.5.3.
- crypt-tests.patch partially upstreamed
- use zend_extension instead of extension directive in opcache.ini
  [bnc#840350]
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.3: These release fix a bug in the patch for
  CVE-2013-4248 in OpenSSL module and compile failure with ZTS enabled
  in PHP 5.4.
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.2:
  * About 20 bugs were fixed, including security issue in OpenSSL
    module (CVE-2013-4248) and session fixation problem (CVE-2011-4718).
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.1
  * bugfixes incl. security fix in the XML parser
* Fri Nov 22 2013 Ralf Lang <lang@b1-systems.de>
- replace php5-64-bit-post-large-files.patch with php5-big-file-upload.patch
  patch that uses def_t instead of signed long as suggested by upstream
* Fri Nov 22 2013 pgajdos@suse.com
- updated to 5.5.0:
  * Added generators and coroutines.
  * Added the finally keyword.
  * Added a simplified password hashing API.
  * Added support for constant array/string dereferencing.
  * Added scalar class name resolution via ::class.
  * Added support for using empty() on the result of function
    calls and other expressions.
  * Added support for non-scalar Iterator keys in foreach.
  * Added support for list() constructs in foreach statements.
  * Added the Zend OPcache extension for opcode caching.
  * A lot more improvements and fixes.
  * PHP logo GUIDs have been removed.
  * Case insensitivity is no longer locale specific. All case
    insensitive matching for function, class and constant names
    is now performed in a locale independent manner according to
    ASCII rules.
- buildrequire cyrus-sasl-devel explicitely
- suhosin-php54.patch renamed to suhosin-php55.patch
* Mon Nov 18 2013 pgajdos@suse.com
- update to 5.4.22:
  * About 10 bugs were fixed.
  * see http://www.php.net/ChangeLog-5.php#5.4.22 for details
* Wed Oct 30 2013 pgajdos@suse.com
- updatedto 5.4.21:
  * About 10 bugs were fixed.
  * added custom-tmp-dir.patch by Per Jessen
* Sun Oct 13 2013 crrodriguez@opensuse.org
- build with --with-fpm-systemd and install systemd unit
- php5-systemd-unit.patch: tweak systemd unit for openSUSE requirements
- php5-openssl.patch: only openSSL_config() is really needed.
- Recommended for 13.1 and Factory
* Wed Sep 25 2013 pgajdos@suse.com
- updated to 5.4.20:
  * About 30 bugs were fixed.
* Thu Sep  5 2013 pgajdos@suse.com
- updated to 5.4.19:
  * These releases fix a bug in the patch for CVE-2013-4248 in
    OpenSSL module and compile failure with ZTS enabled in PHP 5.4.
* Tue Aug 20 2013 pgajdos@suse.com
- updated to 5.4.18:
  * About 30 bugs were fixed, including security issues CVE-2013-4113
    and CVE-2013-4248.
* Thu Aug  1 2013 crrodriguez@opensuse.org
- php5-per-mod-log.patch: It turns out that requesting per-module
  logging support in 2.4 will not do a thing if the expansion
  of APLOG_USE_MODULE is not visible to all files of the module
  so place it in the header instead.
* Wed Jul 31 2013 crrodriguez@opensuse.org
- php5-per-mod-log.patch Support apache 2.4 per module logging
- php5-apache24-updates.patch Use proper API in apache 2.4
  to determine when the module has to be loaded.
  I made this patches at least a year ago, but for some reason
  they went out of my radar and were not applied to upstream
  Will be submitted again soon.
* Mon Jul 15 2013 pgajdos@suse.com
- updated to 5.4.17:
    Core:
    Fixed bug #64988 (Class loading order affects E_STRICT warning).
    Fixed bug #64966 (segfault in zend_do_fcall_common_helper_SPEC).
    Fixed bug #64960 (Segfault in gc_zval_possible_root).
    Fixed bug #64936 (doc comments picked up from previous scanner run).
    Fixed bug #64934 (Apache2 TS crash with get_browser()).
    Fixed bug #64166 (quoted-printable-encode stream filter incorrectly
    discarding whitespace).
    DateTime:
    Fixed bug #53437 (Crash when using unserialized DatePeriod instance).
    FPM:
    Fixed bug #64915 (error_log ignored when daemonize=0).
    Implemented FR #64764 (add support for FPM init.d script).
    PDO:
    Fixed bug #63176 (Segmentation fault when instantiate 2 persistent
    PDO to the same db server).
    PDO_DBlib:
    Fixed bug #63638 (Cannot connect to SQL Server 2008 with PDO dblib).
    Fixed bug #64338 (pdo_dblib can't connect to Azure SQL).
    Fixed bug #64808 (FreeTDS PDO getColumnMeta on a prepared but not
    executed statement crashes).
    PDO_firebird:
    Fixed bug #64037 (Firebird return wrong value for numeric field).
    Fixed bug #62024 (Cannot insert second row with null using
    parametrized query).
    PDO_mysql:
    Fixed bug #48724 (getColumnMeta() doesn't return native_type for BIT,
    TINYINT and YEAR).
    PDO_pgsql:
    Fixed bug #64949 (Buffer overflow in _pdo_pgsql_error).
    pgsql:
    Fixed bug #64609 (pg_convert enum type support).
    Readline:
    Implement FR #55694 (Expose additional readline variable to prevent
    default filename completion).
    SPL:
    Fixed bug #64997 (Segfault while using RecursiveIteratorIterator
    on 64-bits systems).
* Tue Jun 18 2013 jengelh@inai.de
- Explicitly specify cyrus-sasl build dependency
* Thu Jun 13 2013 pgajdos@suse.com
- updated to 5.4.16
- Core:
  . Fixed bug #64879 (Heap based buffer overflow in quoted_printable_encode,
    CVE 2013-2110). (Stas)
  . Fixed bug #64853 (Use of no longer available ini directives causes crash on
    TS build). (Anatol)
  . Fixed bug #64729 (compilation failure on x32). (Gustavo)
  . Fixed bug #64720 (SegFault on zend_deactivate). (Dmitry)
  . Fixed bug #64660 (Segfault on memory exhaustion within function definition).
    (Stas, reported by Juha Kylmänen)
- Calendar:
  . Fixed bug #64895 (Integer overflow in SndToJewish). (Remi)
- Fileinfo:
  . Fixed bug #64830 (mimetype detection segfaults on mp3 file). (Anatol)
- FPM:
  . Ignore QUERY_STRING when sent in SCRIPT_FILENAME. (Remi)
  . Fixed some possible memory or resource leaks and possible null dereference
    detected by code coverity scan. (Remi)
  . Log a warning when a syscall fails. (Remi)
  . Add --with-fpm-systemd option to report health to systemd, and
    systemd_interval option to configure this. The service can now use
    Type=notify in the systemd unit file. (Remi)
- MySQLi
  . Fixed bug #64726 (Segfault when calling fetch_object on a use_result and DB
    pointer has closed). (Laruence)
- Phar
  . Fixed bug #64214 (PHAR PHPTs intermittently crash when run on DFS, SMB or
    with non std tmp dir). (Pierre)
- SNMP:
  . Fixed bug #64765 (Some IPv6 addresses get interpreted wrong).
    (Boris Lytochkin)
  . Fixed bug #64159 (Truncated snmpget). (Boris Lytochkin)
- Streams:
  . Fixed bug #64770 (stream_select() fails with pipes returned by proc_open()
    on Windows x64). (Anatol)
- Zend Engine:
  . Fixed bug #64821 (Custom Exceptions crash when internal properties
    overridden). (Anatol)
* Fri May 10 2013 pgajdos@suse.com
- updated to 5.4.15:
    Core:
    Fixed bug #64578 (debug_backtrace in set_error_handler
    corrupts zend heap: segfault).
    Fixed bug #64458 (dns_get_record result with string of
    length -1).
    Fixed bug #64433 (follow_location parameter of context
    is ignored for most response codes).
    Fixed bug #47675 (fd leak on Solaris).
    Fixed bug #64577 (fd leak on Solaris).
    Fileinfo:
    Upgraded libmagic to 5.14.
    Streams:
    Fixed Windows x64 version of stream_socket_pair() and
    improved error handling.
    Zip:
    Fixed bug #64342 (ZipArchive::addFile() has to check
    for file existence).
* Fri Apr 26 2013 adaugherity@tamu.edu
- Conflict with php53 packages so zypper doesn't suggest installing a
  mix of php53-* (from SLES 11) and php5-* (these 5.4 packages).
* Fri Apr 26 2013 adaugherity@tamu.edu
- Fix build on SLES 11 (no firebird) and openSUSE <= 12.1 (no separate
  libfbclient2-devel pkg).
* Mon Apr 22 2013 pgajdos@suse.com
- use current install-pear-nozlib.phar from
  http://pear.php.net/install-pear-nozlib.phar
- php5-pear package provides/obsoletes php5-pear-Archive_Tar,
  see explanation in the spec
* Wed Apr 17 2013 slavb18@gmail.com
- add php5-firebird providing php5-interbase and php5-pdo_firebird
* Mon Apr 15 2013 pgajdos@suse.com
- updated to 5.4.14:
    Core:
    Fixed bug #64529 (Ran out of opcode space).
    Fixed bug #64515 (Memoryleak when using the same variablename
    two times in function declaration).
    Fixed bug #64432 (more empty delimiter warning in strX methods).
    Fixed bug #64417 (ArrayAccess::&offsetGet() in a trait causes
    fatal error).
    Fixed bug #64370 (microtime(true) less than $_SERVER['REQUEST_TIME_FLOAT']).
    Fixed bug #64239 (Debug backtrace changed behavior since 5.4.10
    or 5.4.11).
    Fixed bug #63976 (Parent class incorrectly using child constant
    in class property).
    Fixed bug #63914 (zend_do_fcall_common_helper_SPEC does not
    handle exceptions properly).
    Fixed bug #62343 (Show class_alias In get_declared_classes()).
    PCRE:
    Merged PCRE 8.32.
    SNMP:
    Fixed bug #61981 (OO API, walk: $suffix_as_key is not working correctly).
    Zip:
    Fixed bug #64452 (Zip crash intermittently). (Anatol)
* Mon Apr 15 2013 pgajdos@suse.com
- libc-client.so needs -lssl
* Fri Apr  5 2013 pgajdos@suse.com
- fixed 'http limits uploads to 2GB' [bnc#812800], see
  https://bugs.php.net/bug.php?id=44522
  * 64bit-post-large-files.patch
* Thu Mar 21 2013 pgajdos@suse.com
- updated to 5.4.13:
    Core:
    Fixed bug #64235 (Insteadof not work for class method in 5.4.11).
    Implemented FR #64175 (Added HTTP codes as of RFC 6585).
    Fixed bug #64142 (dval to lval different behavior on ppc64).
    Fixed bug #64070 (Inheritance with Traits failed with error).
    CLI server:
    Fixed bug #64128 (buit-in web server is broken on ppc64).
    Mbstring:
    mb_split() can now handle empty matches like preg_split() does.
    OpenSSL:
    Fixed bug #61930 (openssl corrupts ssl key resource when using openssl_get_publickey()).
    PDO_mysql:
    Fixed bug #60840 (undefined symbol: mysqlnd_debug_std_no_trace_funcs).
    Phar:
    Fixed timestamp update on Phar contents modification.
    SOAP
    Added check that soap.wsdl_cache_dir conforms to open_basedir (CVE-2013-1635).
    Disabled external entities loading (CVE-2013-1643, CVE-2013-1824).
    SPL:
    Fixed bug #64264 (SPLFixedArray toArray problem).
    Fixed bug #64228 (RecursiveDirectoryIterator always assumes SKIP_DOTS).
    Fixed bug #64106 (Segfault on SplFixedArray[][x] = y when extended).
    Fixed bug #52861 (unset fails with ArrayObject and deep arrays).
    SNMP:
    Fixed bug #64124 (IPv6 malformed).
* Thu Mar 21 2013 pgajdos@suse.com
- updated to 5.4.12:
  * dropped sqlite.so (no longer shipped with 5.4)
  * dropped t1lib support
  * dropped %%{suse_version} 10.x support
  * see /usr/share/doc/packages/php5/UPGRADING or
    http://svn.php.net/viewvc/php/php-src/branches/PHP_5_4/UPGRADING
    for details
  * source changes:
    D    php-5.2.9-BNC-457056.patch -- renamed to php5-BNC-457056.patch
    D    php-5.3.0-bnc513080.patch -- there's no relevant code in exif.c
    D    php-5.3.1-systzdata-v7.patch -- renamed to php5-systzdata-v7.patch
    D    php-5.3.2-aconf26x.patch -- dropped, it is not needed yet
    D    php-5.3.2-ini.patch -- renamed to php5-ini.patch
    D    php-5.3.2-no-build-date.patch -- renamed to php5-no-build-date.patch
    D    php-5.3.22.tar.bz2 -- old tarball
    D    php-5.3.4-format-string-issues.patch -- renamed to php5-format-string-issues.patch
    D    php-5.3.4-pts.patch -- renamed to php5-pts.patch
    D    php-5.3.6-gcc_builtins.patch -- renamed to php5-gcc_builtins.patch
    D    php-5.3.6-ini-date.timezone.patch -- part of php5-ini.patch
    D    php-5.3.8-CVE-2011-4153.patch -- fixed in 5.4 branch
    D    php-5.3.8-crypt-tests.patch -- renamed to php5-crypt-tests.patch
    D    php-5.3.8-no-reentrant-crypt.patch -- renamed to php5-no-reentrant-crypt.patch
    A    php-5.4.13.tar.bz2 -- new version tarball
    D    php-cloexec.patch -- renamed to php5-cloexec.patch
    M    php-suse-addons.tar.bz2 -- content of tar balls are actualy equal
    A    php5-BNC-457056.patch -- renamed from php-5.2.9-BNC-457056.patch, not rebased
    A    php5-cloexec.patch -- renamed from php-cloexec.patch, rebased
    A    php5-sytzdata-v7.patch -- renamed from sytzdata-v7.pach, not rebased
    A    php-format-string-issues.patch -- renamed from php5-5.3.4-format-string-issues.patch, not rebased
    A    php5-crypt-tests.patch -- renamed from php-5.3.8-crypt-tests.patch, not rebased
    A    php5-gcc_builtins.patch -- renamed from php-5.3.6-gcc_builtins.patch, not rebased
    A    php5-ini.patch -- renamed from php-5.3.2-ini.patch, rebased
    A    php5-mbstring-missing-return.patch -- new patch, missing return
    M    php5-missing-extdeps.patch -- rebased
    A    php5-no-build-date.patch -- renamed from php-5.3.2-no-build-date.patch, rebased
    A    php5-no-reentrant-crypt.patch -- renamed from php-5.3.8-no-reentrant-crypt.patch, not rebased
    M    php5-openssl.patch -- rebased
    M    php5-phpize.patch -- rebased
    A    php5-pts.patch -- renamed from php-5.3.4-pts.patch, not rebased
    A    php5-suhosin-php54.patch -- patch on top of suhosin-0.9.33.tgz to work with php 5.4
    M    php5.changes -- this change log
    M    php5.spec -- new version, etc
    D    suhosin-patch-5.3.3-0.9.10.patch.gz -- dropped, seems not be used for some time
* Mon Feb 25 2013 pgajdos@suse.com
- updated to 5.3.22:
  . Fixed bug #64099 (Wrong TSRM usage in zend_Register_class alias). (Johannes)
  . Fixed bug #63899 (Use after scope error in zend_compile). (Laruence)
  . Fixed bug #63943 (Bad warning text from strpos() on empty needle).
    (Laruence)
  . Fixed bug #55397 (comparsion of incomplete DateTime causes SIGSEGV).
    (Laruence, Derick)
  . Fixed bug #63999 (php with fpm fails to build on Solaris 10 or 11). (Adam)
  . Added check that soap.wsdl_cache_dir conforms to open_basedir
    (CVE-2013-1635). (Dmitry)
  . Disabled external entities loading (CVE-2013-1643). (Dmitry)
  . Fixed bug #64106 (Segfault on SplFixedArray[][x] = y when extended). (Nikita Popov)
* Thu Feb  7 2013 pgajdos@suse.com
- updated to 5.3.21:
  * Fixed bug #63762 (Sigsegv when Exception::$trace is changed by user).
  * Fixed bug (segfault due to libcurl connection caching).
  * Fixed bug #63795 (CURL >= 7.28.0 no longer support value 1 for CURLOPT_SSL_VERIFYHOST).
  etc. see NEWS for details
* Thu Oct 18 2012 pgajdos@suse.com
- fix CVE-2011-4153 CVE-2011-4153 [bnc#741859]
* Tue Oct 16 2012 coolo@suse.com
- add explicit buildrequire on libbz2-devel
  (having to patch old .changes file to avoid "double entry")
* Thu Oct 11 2012 pgajdos@suse.com
- updated to 5.3.17:
  * Fixed bug (segfault while build with zts and GOTO vm-kind)
  * Fixed bug #62844 (parse_url() does not recognize //
  * etc. see NEWS for details
* Mon Aug 27 2012 pgajdos@suse.com
- use FilesMatch with 'SetHandler' rather than 'AddHandler'
  [bnc#775852]
* Mon Aug 27 2012 pgajdos@suse.com
- updated to 5.3.16:
  * fixes over 20 bugs, see NEWS for more details
* Wed Jul 25 2012 pgajdos@suse.com
- updated to 5.3.15:
  * fixes over 30 bugs and includes a fix for a security related
    overflow issue in the stream implementation (CVE-2012-2688)
    [bnc#772582] and open_basedir bypass, CVE-2012-3365 [bnc#772580]
* Mon Jun 18 2012 pgajdos@suse.com
- updated to 5.3.14:
  * bug-fix release, see NEWS for details
* Fri May 25 2012 pgajdos@suse.com
- updated to 5.3.13: various security fixes,
  CVE-2012-1823, CVE-2012-2311, CVE-2012-2335, CVE-2012-2336
  * removed php-5.3.10-pcre_fullinfo.patch
  * refreshed php-5.3.2-aconf26x.patch
* Thu Mar  8 2012 coolo@suse.com
- fix license to spdx.org format
* Tue Feb 28 2012 pgajdos@suse.com
- fixed build with new pcre (php bug 60986)
* Sat Feb  4 2012 crrodriguez@opensuse.org
- Build with -fpie
* Thu Feb  2 2012 crrodriguez@opensuse.org
- PHP 5.3.10, fixes CVE-2012-0830.
* Sat Jan 28 2012 crrodriguez@opensuse.org
- remove unapplied patches
* Wed Jan 18 2012 pgajdos@suse.com
- buildrequire libjpeg-devel
* Tue Jan 17 2012 pgajdos@suse.com
- remove apache module conflict with apache2-worker [bnc#728671]
- amended README.SUSE instead
* Wed Jan 11 2012 crrodriguez@opensuse.org
- Update to version 5.3.9
  * Drop already applied patches
  * This update only contain minor bug fixes, it is a stop over
    php 5.4.0 that should be out very soon.
* Mon Jan  2 2012 pgajdos@suse.com
- security update:
  * CVE-2011-4885 [bnc#738221] -- added max_input_vars directive
    to prevent attacks based on hash collisions
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Tue Dec 20 2011 pgajdos@suse.com
- apache module conflicts with apache2-worker [bnc#728671]
* Fri Dec 16 2011 pgajdos@suse.com
- security update:
  * CVE-2011-4566 [bnc#733590]
  * CVE-2011-1466 [bnc#736169]
* Tue Dec  6 2011 coolo@suse.com
- fix license - there is no 3.1 version of php license
* Tue Nov 29 2011 pgajdos@suse.com
- build php against system's libcrypt, which drops
  extended DES support
  * crypt-tests.patch
  * no-reentrant-crypt.patch
* Mon Nov  7 2011 pgajdos@suse.com
- security update:
  CVE-2011-3379 [bnc#728350]
* Sun Sep 18 2011 crrodriguez@opensuse.org
- Fix wrong PAGE_SIZE assumption, must use sysconf() instead
- Fix integer overflow when attempting to use more than 2 Gb
  of memory.
* Mon Sep  5 2011 crrodriguez@opensuse.org
- call openssl_config too in order to load user-provided
  engine configuration.
* Sat Sep  3 2011 crrodriguez@opensuse.org
- Cleanup patches for upcoming release.
* Sun Aug 28 2011 andrea.turrini@gmail.com
- Fixed typos in php5.spec
* Tue Aug 23 2011 crrodriguez@opensuse.org
- Fix very publicized critical bug in crypt() implementation
* Fri Aug 12 2011 crrodriguez@opensuse.org
- Add mssql support with freetds
- Update PHP snapshot.
* Tue Aug  9 2011 crrodriguez@opensuse.org
- Update snapshot, more static analyzer fixes.
* Sun Aug  7 2011 crrodriguez@opensuse.org
- Update snapshot, fix converity warnings
* Fri Aug  5 2011 crrodriguez@opensuse.org
- Update snapshot, several check if malloc() succeeded.
* Wed Aug  3 2011 crrodriguez@opensuse.org
- Fix build in Factory
- Fix Segfault with allow_call_time_pass_reference = Off
- Using class constants in array definition fails
* Mon Aug  1 2011 crrodriguez@opensuse.org
- Add sqlite3 session storage, this is no more than
  a forward port of already existent sqlite2 backend
* Sun Jul 31 2011 crrodriguez@opensuse.org
- Update snap, PHP 5.3.7-RC4
* Wed Jul 27 2011 crrodriguez@opensuse.org
- Update snapshot again.
* Sat Jul 23 2011 crrodriguez@opensuse.org
- Update snapshot.
* Thu Jul 14 2011 crrodriguez@opensuse.org
- is_a() function is throwing an annoying warning
  "Unknown class passed as parameter" which is noticeable when
  you use PEAR, fix it, if your code uses it you should be
  using the instanceof operator anyway.
- Update bundled pear.
* Mon Jul 11 2011 crrodriguez@opensuse.org
- Crash in gc_remove_zval_from_buffer CVE-NO-NAME
- Crash in zend_mm_check_ptr // Heap corruption
* Wed Jul  6 2011 crrodriguez@opensuse.org
- Fixed missing Expires and Cache-Control headers for ping and status pages
- fix crypt() issue with overlong salt
- Fixed bug #52935 (call exit in user_error_handler cause stream relate core).
* Mon Jun 27 2011 crrodriguez@opensuse.org
- Fix crash in error_log (strlen with NULL)
- Fixed exit at FPM startup on fpm_resources_prepare
- Added master rlimit_files and rlimit_core
- Removed pid in debug logs written by chrildren processes
- Replaced shm_slots with a real scoreboard
* Wed Jun 22 2011 crrodriguez@opensuse.org
- Enable mysqlnd compression protocol.
* Thu Jun 16 2011 crrodriguez@opensuse.org
- Update snapshot to 5.3.7 RC1
* Tue Jun 14 2011 crrodriguez@opensuse.org
- Allow bison 2.5
-File path injection vulnerability in RFC1867 File upload CVE-2011-2202.
* Fri Jun 10 2011 crrodriguez@opensuse.org
- Update 5.3 snap
- Fix compiler failure that happended after compile error.
- Stream not closed and error not returned when SSL CN_match fails.
* Mon Jun  6 2011 crrodriguez@opensuse.org
- Update 5.3 snap
- Update bundled PEAR
- Case discrepancy in timezone names cause Uncaught exception and fatal error.
- SEEK_CUR with 0 value, returns a warning
- Restore fix: do not accept paths with NULL in them
* Fri Jun  3 2011 crrodriguez@opensuse.org
- Update to version 5.3.6.201106031621
- Crash when calling call_user_func with unknown function name
- Fixed double registering of browscap ini directive
* Sun May 29 2011 crrodriguez@opensuse.org
- Drop Update alternatives usage, there are no alternatives
  PHP4 is gone and PHP6 is not coming at any time soon.
- Remove "mm" support from session module, virtually nothing
  uses it and it doesnt support proper locking, mount
  /var/lib/php5 in tmpfs instead.
* Sun May 29 2011 crrodriguez@opensuse.org
- Update to 5.3.6.201105291701
  * Fixes random crash with apache2 SAPI and php_admin_value
  in virtualhost configuration.
* Fri May 20 2011 crrodriguez@opensuse.org
- Update 5.3 branch
- Fix a few memory leaks
- Check if tempfile can be created in phar extension
- Fix problems with __halt_compiler and imported namespaces
- Properly handle out of memory conditions in mysqlnd
* Sat May 14 2011 crrodriguez@opensuse.org
- Update 5.3 branch.
- Fix user after free in xmlreader extension.
* Mon May  9 2011 crrodriguez@opensuse.org
- Update to current 5.3 svn version.
- For practical reasons now the hash extension is built-in,hence
  deprecates package php5-hash, it is nowdays required by the session
  and phar extensions but must be statically built to work.
- Drop php5-session patch, needed only to workaround compile
  failure when hash extension is built as loadable extension.
- php.ini now clearly says that by "3" in session.hash_function
  we mean SHA256.
* Fri Apr 29 2011 crrodriguez@opensuse.org
- Update to a recent 5.3.x SVN version, mostly bug fixes
  * track_errors causes segfault
  * classes from dl()'ed extensions are not destroyed
  * Crash when assigning value to a dimension in a non-array
  * use-after-free in substr_replace()
* Wed Apr 13 2011 crrodriguez@opensuse.org
- fix crash on destruction.
- allow openssl extension to be built w/o SSLv2
* Tue Apr  5 2011 lang@b1-systems.de
- Add a default to date.timezone  because php5 warns that this is a required setting and clutters up the output in zypper installations of pear packages and other places
- Versions after 5.3.6 may make this fatal
* Sat Apr  2 2011 crrodriguez@opensuse.org
- Intl extension failed to load [bnc#659868]
- Fix update-alternatives usage,will be dropped in the future.
* Mon Mar 28 2011 sbutler1@illinois.edu
- Add tcpd-devel for building the SNMP extension on SLE_10 and apache_server_SLE_10.
* Thu Mar 17 2011 crrodriguez@opensuse.org
- Update to php 5.3.6 final
  * Enforce security in the fastcgi protocol parsing with fpm SAPI.
  * Fixed bug #54247 (format-string vulnerability on Phar). (CVE-2011-1153)
  * Fixed bug #54193 (Integer overflow in shmop_read()). (CVE-2011-1092)
  * Fixed bug #54055 (buffer overrun with high values for precision ini setting).
  * Fixed bug #54002 (crash on crafted tag in exif). (CVE-2011-0708)
  * Fixed bug #53885 (ZipArchive segfault with FL_UNCHANGED on empty archive). (CVE-2011-0421)
* Wed Mar 16 2011 crrodriguez@opensuse.org
- Upgrade to PHP 5.3.6.RC3
  * Drop obsoleted patches
  * fix some rpmlint warnings
  * Hundreds of changes, see NEWS for details
* Wed Mar  9 2011 crrodriguez@opensuse.org
- Fix more date in binaries causing pointless republish of pkgs.
* Fri Feb 25 2011 chris@computersalat.de
- fix for macros.php
  o devel pkg must have Obsoletes/Provides: php-macros
* Tue Feb 22 2011 pgajdos@suse.cz
- security fixes
  * CVE-2011-0420 [bnc#672933]
  * CVE-2011-0708 [bnc#671710]
* Thu Feb 10 2011 chris@computersalat.de
- extend macros.php
  o __php, __phpize, __php_config, php_version
  o __pear, php_peardir, php_pearxmldir
  o php_pear_gen_filelist
- add README.macros
* Thu Jan 13 2011 pgajdos@suse.cz
- security fix:
  * fopen_https_proxy_auth_fix.patch [bnc#656523]
* Mon Jan 10 2011 cristian.rodriguez@opensuse.org
- export PHP_MYSQLND_ENABLED=yes to solve the mysqlnd problem
  when extensions are built shared. [bnc#661464]
* Mon Jan 10 2011 cristian.rodriguez@opensuse.org
- Go back to libmysql as there is currently no way
  to build shared mysql extensions with mysqlnd. [bnc#661464]
* Sun Jan  9 2011 cristian.rodriguez@opensuse.org
- Use mysqlnd driver, this is a newer PHP-native mysql
  extension, that does not require external libraries.
  Now you can use mysql, mariadb or drizzle without extra libs.
  fixes bnc #661464 and other old feature requests.
* Thu Jan  6 2011 cristian.rodriguez@opensuse.org
- Update to version 5.3.5, Critical Update
  * Fixed bug #53632 (PHP hangs on numeric value 2.2250738585072011e-308). (CVE-2010-4645)
  Only 32 bit binaries affected, confirmed in factory i586.
* Fri Dec 17 2010 cristian.rodriguez@opensuse.org
- revert unsuitable patch php-5.3.4-dlopen.patch
* Tue Dec 14 2010 cristian.rodriguez@opensuse.org
- Add  php-5.3.4-dlopen.patch from fedora,makes dlopen to use
  bind_now instead of lazy.
- Compiler is now in C99 mode for both core and extensions.
* Tue Dec 14 2010 cristian.rodriguez@opensuse.org
- fix format string bug in Phar extension I just found
  http://bugs.php.net/bug.php?id=53541 and the underlying
  issue, which is the lack of format attributes in several
  core prototypes.
* Mon Dec 13 2010 cristian.rodriguez@opensuse.org
- Update to PHP 5.3.4 final
  * Fixed crash in zip extract method (possible CWE-170).
  * Paths with NULL in them (foo\0bar.txt) are now considered as invalid (CVE-2006-7243).
  * Fixed a possible double free in imap extension (Identified by Mateusz Kocielski). (CVE-2010-4150).
  * Fixed NULL pointer dereference in ZipArchive::getArchiveComment. (CVE-2010-3709).
  * Fixed possible flaw in open_basedir (CVE-2010-3436).
  * Fixed MOPS-2010-24, fix string validation. (CVE-2010-2950).
  * Fixed symbolic resolution support when the target is a DFS share.
  * Fixed bug #52929 (Segfault in filter_var with FILTER_VALIDATE_EMAIL with large amount of data) (CVE-2010-3710).
  * Key Bug Fixes in PHP 5.3.4 include:
  * Added stat support for zip stream.
  * Added follow_location (enabled by default) option for the http stream support.
  * Added a 3rd parameter to get_html_translation_table. It now takes a charset hint, like htmlentities et al.
  * Implemented FR #52348, added new constant ZEND_MULTIBYTE to detect zend multibyte at runtime.
  * Multiple improvements to the FPM SAPI.
  * Over 100 other bug fixes.
- SUSE specific;
  * enable PTY support in proc_open (temporary)
* Wed Nov 24 2010 ro@suse.de
- xft-config is gone
* Tue Nov  2 2010 cristian.rodriguez@opensuse.org
- Update to 5.3.3_svn201011020214
  * Fix Performance issue, array_diff may take hours instead
  of seconds in some scenarios,regression appeared in version
  5.2.5
* Wed Oct 27 2010 cristian.rodriguez@opensuse.org
- Update to 5.3.3_svn20101027xx
- Fix init script again.
* Thu Oct 14 2010 crrodriguez@opensuse.org
- update to 5.3.3_svn201010140300
- Fix php-fpm init script.
* Sat Oct  9 2010 cristian.rodriguez@opensuse.org
- Update to an slightly newer PHP 5.3.3.x snap, fixes
  around 100 bugs including open_basedir problems.
- add the fpm sapi to the package.
* Tue Aug  3 2010 cristian.rodriguez@opensuse.org
- Clarify changelog this update fixed:
  * VUL-0: php5 new unserialize() flaw CVE-2010-2225 [bnc#616232]
  * VUL-0: php5: MOPS-2010-021: fnmatch() Stack Exhaustion Vulnerability [bnc#605097]
  * VUL-0: php5: MOPS-2010-017: preg_quote() Interruption Information Leak [bnc#605100]
  * VUL-0: php5: MOPS-2010-022 use after free [bnc#609763]
  * VUL-0: php5-phar: MOPS-2010-0{24,25,26,27,28} format string bugs [bnc#609766]
  * VUL-0: php5: MOPS-2010-0{32,33,34} use space interruption in iconv functions [bnc#609768]
  * VUL-0: php5: MOPS-2010-0{36,37,38,39,40} userspace interruptions [bnc#609769]
  * VUL-0: php5: MOPS-2010-0{36..46} userspace interruptions [bnc#609769]
  * VUL-0: php5: MOPS-2010-047/048 information leak [bnc#612555]
  * VUL-0: php5: MOPS-2010-049/50/51/52/53/54/55 memory corruption and/or info leak [bnc#612556]
  * VUL-0: PHP5: Session Data Injection Vulnerability [bnc#619483]
  * VUL-0: PHP5: multiple heap based buffer overflows [bnc#619486]
  * bugzilla numbers 619487,619489,619469,609766..
* Tue Jul 20 2010 cristian.rodriguez@opensuse.org
- Update to PHP 5.3.3 RC3
- Massive lot of security fixes see list
  here http://www.php-security.org/category/vulnerabilities/index.html
* Tue Jun  1 2010 cristian.rodriguez@opensuse.org
- possible fix for [bnc#610633]
* Fri Apr 16 2010 crrodriguez@opensuse.org
- use FD_CLOEXEC flag to avoid annoying races.
* Sun Apr  4 2010 crrodriguez@opensuse.org
- remove obsolete buildRequires
* Fri Apr  2 2010 crrodriguez@opensuse.org
- remove build date from binaries so they dont get
  republished every time
- fix invalid path
* Thu Apr  1 2010 crrodriguez@opensuse.org
-  add missing patch, refresh patches with -p0
* Thu Apr  1 2010 crrodriguez@opensuse.org
- Update to PHP 5.3.2, see NEWS for details
* Fri Mar  5 2010 dimstar@opensuse.org
- Add php5-autoconf-2.65.patch to fix build with autoconf 2.65; it's
  a backported combination of svn commits 291283, 291284 and
  291332.
- Workaround old php bug http://bugs.php.net/bug.php?id=21153 by
  replacing -ledit with -ledit -lncurses in the resulting configure
  scripts. This became apparent problem due to libedit being built
  with as-needed now.
- Add php5-bug51224.patch to fix buffer overflows happening in
  strcpy. It;s a combination of upstream svn revs 284097 and 284099
* Sun Jan 17 2010 vuntz@opensuse.org
- Remove unneeded gtk-devel BuildRequires.
* Mon Jan 11 2010 aj@suse.de
- Remove obsolete build requires of orbit-devel.
* Tue Dec 22 2009 jengelh@medozas.de
- avoid alignment crash on alignment-sensitive CPUs
  (bugs.php.net#46074)
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Tue Oct  6 2009 crrodriguez@opensuse.org
- Fixed wrong harcoded mysql socket  [bnc#544516]
- Fixed wrong default include_path
* Tue Sep  8 2009 crrodriguez@suse.de
- make php5-pear noarch in Factory
* Wed Aug 26 2009 crrodriguez@suse.de
- remove obsolete patches
- apply ini patch
- enable mhash compatibility in the hash extension and obsolete php5-mhash
- add macros.php to the source list
* Mon Aug 24 2009 crrodriguez@suse.de
- PHP read_exif_data() only returns the first letter of UTF-16 strings [bnc#518300]
* Sun Aug 23 2009 crrodriguez@suse.de
- fix missing return values of suhosin extension
* Wed Aug 19 2009 crrodriguez@novell.com
- fix build on CODE10 products
* Wed Aug 19 2009 crrodriguez@novell.com
- fix horrible broken open_basedir functionality
* Sun Aug 16 2009 crrodriguez@suse.de
- update suhosin extension to version 0.9.29
- mysql extensions now use mysqlnd instead of libmysqlclient.
- enable sqlite3 extension, part of the php5-sqlite package
- enable enchant extension
- enable fileinfo extension
- enable intl extension
* Fri Aug 14 2009 crrodriguez@suse.de
- add suhosin patch and newer suhosin extension for compatibility
  reasons
* Thu Aug 13 2009 crrodriguez@suse.de
-  Upgrade to PHP 5.3, see http://www.php.net/ChangeLog-5.php
  for the huge list of changes
-  remove dbase and ncurses extension
* Thu Jul 16 2009 coolo@novell.com
- disable as-needed to fix build
* Fri Jun 19 2009 crrodriguez@suse.de
- update to PHP 5.2.10
  * Fixed bug #48378 (exif_read_data() segfaults on certain corrupted .jpeg files)
  * Added "ignore_errors" option to http fopen wrapper. (David Zulke, Sara)
  * Fixed memory corruptions while reading properties of zip files. (Ilia)
  * Fixed memory leak in ob_get_clean/ob_get_flush. (Christian)
  * Fixed segfault on invalid session.save_path. (Hannes)
  * Fixed leaks in imap when a mail_criteria is used. (Pierre)
  * Changed default value of array_unique()'s optional sorting type parameter back to SORT_STRING to fix backwards compatibility breakage introduced in PHP 5.2.9. (Moriyoshi)
  * Fixed bug #47940 (memory leaks in imap_body). (Pierre, Jake Levitt)
  * Fixed bug #47903 ("@" operator does not work with string offsets). (Felipe)
  * Fixed bug #47644 (Valid integers are truncated with json_decode()). (Scott)
  * Fixed bug #47564 (unpacking unsigned long 32bit big endian returns wrong result). (Ilia)
  * Fixed bug #47365 (ip2long() may allow some invalid values on certain 64bit systems).
  * Over 100 bug fixes.
* Thu May 21 2009 crrodriguez@suse.de
- add temporary backport of openssl prng function
* Sat Mar 14 2009 crrodriguez@suse.de
- Update to version 5.2.9, security and bugfix release
  * VUL-0: php5: memory disclosure by imagerotate() [bnc#480850]
  * VUL-0: php5: mbstring.func_overload set in .htaccess becomes global [bnc#471419]
  * Fixed a segfault when malformed string is passed to json_decode()
  * Fixed explode() behavior with empty string to respect negative limit.
* Sun Dec 14 2008 crrodriguez@suse.de
- remove ming extension, moved to server:php:extensions later
* Tue Dec  9 2008 crrodriguez@suse.de
- Update to PHP 5.2.8
* Mon Dec  8 2008 crrodriguez@suse.de
- fix BLOCKER magic_quotes breakage, if your code
  relies on this feature, it is broken,time to press the panic button.
* Fri Dec  5 2008 crrodriguez@suse.de
- update to PHP 5.2.7 final, no mayor changes since RC5
* Fri Nov 28 2008 crrodriguez@suse.de
- update to PHP 5.2.7RC5 see news for details
* Fri Nov 21 2008 crrodriguez@suse.de
- update to PHP 5.2.7RC4, see news for details
* Sun Nov 16 2008 crrodriguez@suse.de
- update to PHP 5.2.7RC3, see NEWS for details
* Mon Sep  8 2008 crrodriguez@suse.de
- update suhosin to version 0.9.27
  * Fixed problem with suhosin.perdir
    Thanks to Hosteurope for tracking this down
  * Fixed problems with ext/uploadprogress
    Reported by: Christian Stocker
  * Added suhosin.srand.ignore and suhosin.mt_srand.ignore (default: on)
  * Modified rand()/srand() to use the Mersenne Twister algorithm with separate state
  * Added better internal seeding of rand() and mt_rand()
* Sun Jul 13 2008 crrodriguez@suse.de
- merge patches from schwab
* Fri May  2 2008 crrodriguez@suse.de
- update to PHP 5.2.6
  * Fixed possible stack buffer overflow in the FastCGI SAPI identified by Andrei Nigmatulin.
  * Fixed integer overflow in printf() identified by Maksymilian Aciemowicz.
  * Fixed security issue detailed in CVE-2008-0599 identified by Ryan Permeh.
  * Fixed a safe_mode bypass in cURL identified by Maksymilian Arciemowicz.
  * Properly address incomplete multibyte chars inside escapeshellcmd() identified by Stefan Esser.
  * Fixed two possible crashes inside the posix extension.
  * Fixed bug #44069 (Huge memory usage with concatenation using . instead of .=)
  * Fixed bug #44141 (private parent constructor callable through static function).
  * Fixed bug #43589 (a possible infinite loop in bz2_filter.c).
  * Fixed bug #43450 (Memory leak on some functions with implicit object __toString() call).
  * Fixed bug #43201 (Crash on using uninitialized vals and __get/__set).
  * Fixed bug #42978 (mismatch between number of bound params and values causes a crash in pdo_pgsql).
  * Fixed bug #42937 (__call() method not invoked when methods are called on parent from child class).
  * Fixed bug #42736 (xmlrpc_server_call_method() crashes).
  * Fixed bug #42369 (Implicit conversion to string leaks memory).
  * Fixed bug #41562 (SimpleXML memory issue).
  * Fixed bug #43606 (define missing depencies of the exif extension). (crrodriguez at suse dot de)
  * Fixed bug #43498 (file_exists() on a proftpd server got SIZE not allowed in ASCII mode). (Ilia, crrodriguez at suse dot de)
  * Over 120 bug fixes.
* Tue Feb  5 2008 crrodriguez@suse.de
- update suhosin extension to version 0.9.23
- Fixed suhosin extension now compiles with snapshots of PHP 5.3
- Fixed crypt() behaves like normal again when there is no salt supplied
- wrong Obsoletes causes upgrade trouble [bnc #355618]
* Fri Feb  1 2008 mmarek@suse.cz
- use %%%%_with_ming and %%%%_with_qdbm instead of %%%%opensuse_bs,
  enables building in the bs in other projects than server:php
  (bnc#357917)
* Fri Jan 11 2008 crrodriguez@suse.de
- Try patch recently published by Redhat that allows PHP to
  use the system timezone database instead of the bundled one.
* Mon Jan  7 2008 crrodriguez@suse.de
- Do not hard require php5-timezonedb, instead provide a capability
  php(tzdatabase) = builtin_tz_ver so it gets installed via rpm
  Supplements only when needed.
* Thu Dec 27 2007 crrodriguez@suse.de
- PHP is leaking file descriptors badly on relative includes
  (php-5.2.5-fdleak.patch)
* Thu Dec 13 2007 crrodriguez@suse.de
- suhosin 0.9.22
  - Fixed function_exists() now checks the Suhosin permissions
  - Fixed crypt() salt no longer uses Blowfish by default
  - Fixed .htaccess/perdir support
  - Fixed compilation problem on OS/X
  - Added protection against some attacks through _SERVER variables
  - Added suhosin.server.strip and suhosin.server.encode
* Tue Dec 11 2007 crrodriguez@suse.de
- use /dev/urandom for generating session-IDs [#337005]
- L3: PHP: Venezuela Time Zone Update starting date changed to December 9 [#345548]
* Mon Nov 12 2007 crrodriguez@suse.de
- update to PHP 5.2.5
  * Fixed dl() to only accept filenames. reported by Laurent Gaffie.
  * Fixed dl() to limit argument size to MAXPATHLEN (CVE-2007-4887).
  * Fixed htmlentities/htmlspecialchars not to accept partial multibyte sequences.
  * Fixed possible triggering of buffer overflows inside glibc implementations of the fnmatch(), setlocale() and glob() functions. Reported by Laurent Gaffie.
  * Fixed "mail.force_extra_parameters" php.ini directive not to be modifiable in .htaccess due to the security implications reported by SecurityReason.
  * Fixed bug #42869 (automatic session id insertion adds sessions id to non-local forms).
  * Fixed bug #41561 (Values set with php_admin_* in httpd.conf can be overwritten with ini_set()).
  * Upgraded PCRE to version 7.3 (Nuno)
  * Added optional parameter $provide_object to debug_backtrace(). (Sebastian)
  * Added alpha support for imagefilter() IMG_FILTER_COLORIZE. (Pierre)
  * Added ability to control memory consumption between request using ZEND_MM_COMPACT environment variable. (Dmitry)
  * Improved speed of array_intersect_key(), array_intersect_assoc(), array_uintersect_assoc(), array_diff_key(), array_diff_assoc() and array_udiff_assoc(). (Dmitry)
  * Fixed move_uploaded_file() to always set file permissions of resulting file according to UMASK. (Andrew Sitnikov)
  * Fixed possible crash in ext/soap because of uninitialized value. (Zdash Urf)
  * Fixed regression in glob() when enforcing safe_mode/open_basedir checks on paths containing '*'. (Ilia)
  * Fixed PDO crash when driver returns empty LOB stream. (Stas)
  * Fixed iconv_*() functions to limit argument sizes as workaround to libc bug (CVE-2007-4783, CVE-2007-4840 by Laurent Gaffie). (Christian Hoffmann, Stas)
  * Fixed missing brackets leading to build warning and error in the log. Win32 code. (Andrey)
  * Fixed leaks with multiple connects on one mysqli object. (Andrey)
  * Fixed imagerectangle regression with 1x1 rectangle (libgd #106). (Pierre)
  * Fixed bug #43196 (array_intersect_assoc() crashes with non-array input). (Jani)
  * Fixed bug #43139 (PDO ignores ATTR_DEFAULT_FETCH_MODE in some cases with fetchAll()). (Ilia)
  * Fixed bug #43137 (rmdir() and rename() do not clear statcache). (Jani)
  * Fixed bug #43130 (Bound parameters cannot have - in their name). (Ilia)
  * Fixed bug #43099 (XMLWriter::endElement() does not check # of params). (Ilia)
  * Fixed bug #43020 (Warning message is missing with shuffle() and more than one argument). (Scott)
  * Fixed bug #42976 (Crash when constructor for newInstance() or newInstanceArgs() fails) (Ilia)
  * Fixed bug #42917 (PDO::FETCH_KEY_PAIR doesn't work with setFetchMode). (Ilia)
  * Fixed bug #42890 (Constant "LIST" defined by mysqlclient and c-client). (Andrey)
  * Fixed bug #42818 ($foo = clone(array()); leaks memory). (Dmitry)
  * Fixed bug #42817 (clone() on a non-object does not result in a fatal error). (Ilia)
  * Fixed bug #42785 (json_encode() formats doubles according to locale rather then following standard syntax). (Ilia)
  * Fixed bug #42783 (pg_insert() does not accept an empty list for insertion). (Ilia)
  * Fixed bug #42773 (WSDL error causes HTTP 500 Response). (Dmitry)
  * Fixed bug #42772 (Storing $this in a static var fails while handling a cast to string). (Dmitry)
  * Fixed bug #42767 (highlight_string() truncates trailing comment). (Ilia)
  * Fixed bug #42739 (mkdir() doesn't like a trailing slash when safe_mode is enabled). (Ilia)
  * Fixed bug #42703 (Exception raised in an iterator::current() causes segfault in FilterIterator) (Marcus)
  * Fixed bug #42699 (PHP_SELF duplicates path). (Dmitry)
  * Fixed bug #42654 (RecursiveIteratorIterator modifies only part of leaves) (Marcus)
  * Fixed bug #42643 (CLI segfaults if using ATTR_PERSISTENT). (Ilia)
  * Fixed bug #42637 (SoapFault : Only http and https are allowed). (Bill Moran)
  * Fixed bug #42627 (bz2 extension fails to build with -fno-common). (dolecek at netbsd dot org)
  * Fixed bug #42596 (session.save_path MODE option does not work). (Ilia)
  * Fixed bug #42590 (Make the engine recognize \v and \f escape sequences). (Ilia)
  * Fixed bug #42587 (behavior change regarding symlinked .php files). (Dmitry)
  * Fixed bug #42579 (apache_reset_timeout() does not exist). (Jani)
  * Fixed bug #42549 (ext/mysql failed to compile with libmysql 3.23). (Scott)
  * Fixed bug #42523 (PHP_SELF duplicates path). (Dmitry)
  * Fixed bug #42512 (ip2long('255.255.255.255') should return 4294967295 on 64-bit PHP). (Derick)
  * Fixed bug #42506 (php_pgsql_convert() timezone parse bug) (nonunnet at gmail dot com, Ilia)
  * Fixed bug #42462 (Segmentation when trying to set an attribute in a DOMElement). (Rob)
  * Fixed bug #42453 (CGI SAPI does not shut down cleanly with -i/-m/-v cmdline options). (Dmitry)
  * Fixed bug #42452 (PDO classes do not expose Reflection API information). (Hannes)
  * Fixed bug #42468 (Write lock on file_get_contents fails when using a compression stream). (Ilia)
  * Fixed bug #42488 (SoapServer reports an encoding error and the error itself breaks). (Dmitry)
  * Fixed bug #42378 (mysqli_stmt_bind_result memory exhaustion). (Andrey)
  * Fixed bug #42359 (xsd:list type not parsed). (Dmitry)
  * Fixed bug #42326 (SoapServer crash). (Dmitry)
  * Fixed bug #42214 (SoapServer sends clients internal PHP errors). (Dmitry)
  * Fixed bug #42189 (xmlrpc_set_type() crashes php on invalid datetime values). (Ilia)
  * Fixed bug #42139 (XMLReader option constants are broken using XML()). (Rob)
  * Fixed bug #42086 (SoapServer return Procedure '' not present for WSIBasic compliant wsdl). (Dmitry)
  * Fixed bug #41822 (Relative includes broken when getcwd() fails). (Ab5602, Jani)
  * Fixed bug #39651 (proc_open() append mode doesn't work on windows). (Nuno)
* Thu Aug 30 2007 crrodriguez@suse.de
- update to PHP 5.2.4, no relevant changes since RC3.
* Fri Aug 24 2007 crrodriguez@suse.de
- PHP 5.2.4RC3
- Fixed version_compare() to support "rc" as well as "RC" for release
  candidate version numbers.
- Fixed bug #42368 (Incorrect error message displayed by pg_escape_string).
  (Ilia)
- Fixed phpbug #42365 and Novell bugzilla #292998 (glob() crashes and/or accepts way too many flags). (Jani)
- Fixed bug #42183 (classmap causes crash in non-wsdl mode). (Dmitry)
- Fixed bug #42009 (is_a() and is_subclass_of() should NOT call autoload,
  in the same way as "instanceof" operator). (Dmitry)
- Fixed bug #41904 (proc_open(): empty env array should cause empty
  environment to be passed to process). (Jani)
- Fixed bug #37273 (Symlinks and mod_files session handler allow open_basedir
  bypass). (Ilia)
- remove wrong hardcoded requirement on libedit
- devel package at least does not need libtool the php build enviroment uses a private copy.
- drop no longer needed patches already in upstream
* Fri Aug 17 2007 anosek@suse.cz
- updated to version 5.2.4RC2
  - Fixed oci8 and PDO_OCI extensions to allow configuring with Oracle 11g client
    libraries. (Chris Jones)
  - Fixed bug #42292 ($PHP_CONFIG not set for phpized builds). (Jani)
  - Fixed bug #42261 (header wrong for date field). (roberto at spadim dot com
    dot br, Ilia)
  - Fixed bug #42259 (SimpleXMLIterator loses ancestry). (Rob)
  - Fixed bug #42247 (ldap_parse_result() not defined under win32). (Jani)
  - Fixed bug #42243 (copy() does not output an error when the first arg is a
    dir). (Ilia)
  - Fixed bug #42242 (sybase_connect() crashes). (Ilia)
  - Fixed bug #42237 (stream_copy_to_stream returns invalid values for mmaped
    streams). (andrew dot minerd at sellingsource dot com, Ilia)
  - Fixed bug #42222 (possible buffer overflow in php_openssl_make_REQ). (Pierre)
  - Fixed bug #42211 (property_exists() fails to find protected properties from
    a parent class). (Dmitry)
  - Fixed bug #42208 (substr_replace() crashes when the same array is passed
    more than once). (crrodriguez at suse dot de, Ilia)
  - Fixed bug #42198 (SCRIPT_NAME and PHP_SELF truncated when inside a userdir
    and using PATH_INFO). (Dmitry)
  - Fixed bug #42195 (C++ compiler required always). (Jani)
  - Fixed bug #42117 (bzip2.compress loses data in internal buffer). (Philip,
    Ilia)
  - Fixed bug #42082 (NodeList length zero should be empty). (Hannes)
  - Fixed bug #36492 (Userfilters can leak buckets). (Sara)
  - Fixed bug #31892 (PHP_SELF incorrect without cgi.fix_pathinfo, but turning
    on screws up PATH_INFO). (Dmitry)
* Mon Aug  6 2007 anosek@suse.cz
- updated to version 5.2.4RC1
- dropped obsoleted PHP_5_2-CVS-2007-07-30.patch.bz2
* Mon Jul 30 2007 mmarek@suse.cz
- updated to latest state of PHP_5_2 branch; highlights from the
  NEWS file:
  - Upgraded PCRE to version 7.2 (Nuno)
  - Updated timezone database to version 2007.6. (Derick)
  - Improved openssl_x509_parse() to return extensions in readable
    form.  (Dmitry)
  - Changed "display_errors" php.ini option to accept "stderr" as
    value which makes the error messages to be outputted to STDERR
    instead of STDOUT with CGI and CLI SAPIs (FR #22839). (Jani)
  - Changed error handler to send HTTP 500 instead of blank page on
    PHP errors.  (Dmitry, Andrei Nigmatulin)
  - Added check for unknown options passed to configure. (Jani)
  - Added persistent connection status checker to pdo_pgsql.
    (Elvis Pranskevichus, Ilia)
  - Added support for ATTR_TIMEOUT inside pdo_pgsql driver. (Ilia)
  - Added php_ini_loaded_file() function which returns the path to
    the actual php.ini in use. (Jani)
  - Added GD version constants GD_MAJOR_VERSION, GD_MINOR_VERSION
    GD_RELEASE_VERSION, GD_EXTRA_VERSION and GD_VERSION_STRING.
    (Pierre)
  - Added missing open_basedir checks to CGI.  (anight at
    eyelinkmedia dot com, Tony)
  - Added missing format validator to unpack() function. (Ilia)
  - Added missing error check inside bcpowmod(). (Ilia)
  - Added CURLOPT_PRIVATE & CURLINFO_PRIVATE constants.  (Andrey A.
    Belashkov, Tony)
  - Added missing MSG_EOR and MSG_EOF constants to sockets
    extension. (Jani)
  - Added PCRE_VERSION constant. (Tony)
  - Added ReflectionExtension::info() function to print the
    phpinfo() block for an extension. (Johannes)
  - Implemented FR #41884 (ReflectionClass::getDefaultProperties()
    does not handle static attributes). (Tony)
  - plus lots of bugfixes
- fixed the pear phar archive to run with 5.2.4
  [http://bugs.php.net/bug.php?id=42146]
* Wed Jul 25 2007 mmarek@suse.cz
- added /var/lib/pear to php5-pear.rpm
* Tue Jul 24 2007 judas_iscariote@shorewall.net
- fix nasty deadlock in pear
- update php5-ze2-fixes.patch and actually apply it.
* Tue Jul 17 2007 anosek@suse.cz
- fixed YOU honors Recommends, breaks php update [#291551]
  (moved php-suhosin from Recommends to Suggests)
* Mon Jun 25 2007 mmarek@suse.cz
- provide /srv/www/cgi-bin/php5 compat symlink instead of patching
  config files
* Sat Jun 23 2007 judas_iscariote@shorewall.net
- fixed a mess with update-alternatives PreReq uncovered by newer build versions.
  actually every subpackage that uses update-alternatives should PreReq it.
- fix some ZE2 bugs.
* Tue Jun 12 2007 mmarek@suse.cz
- drop php5.xpm and the Icon: line from the specfile (the icon is
  not used at all and it breaks rpm -q --specfile php5.spec)
* Fri Jun  1 2007 judas_iscariote@shorewall.net
- PHP version 5.2.3 see http://www.php.net/releases/5_2_3.php
- important: PHP-cgi now lives in /usr, package attempts to fix both
  lighttpd and apache2 fastcgi config files.
* Wed May 30 2007 judas_iscariote@shorewall.net
- use system re2c in factory.
- enable support for qbdm in the dba extension (build service only)
- enable the ming extension (build service only)
* Mon May 21 2007 mmarek@suse.cz
- fixed the dba extension adding -ldb-4.x to global LDFLAGS,
  causing unnecessary dependency in /usr/bin/php5
  [http://bugs.php.net/bug.php?id=41455]
* Sat May 19 2007 judas_iscariote@shorewall.net
- updated suhosin to version 0.9.20, security fix + bugfixes
  see http://www.hardened-php.net/suhosin/changelog.html for more detail.
* Mon May 14 2007 judas_iscariote@shorewall.net
- fix devel package, in the reality PHP does not currenly require expat.
  headers provides a expat compatibility layer but it is no longer in use
  by our packages as libxml2 is always prefered, (and HAVE_LIBEXPAT is not defined)
* Fri May 11 2007 judas_iscariote@shorewall.net
- update php5-test-fixes fixing another bug in zend_compile.c
- use rpm macros in the spec file
- when removing apache2-mod_php5, unload it from apache first.
- when updating apache2-mod_php5 restart apache with restart on update macro.
* Sun May  6 2007 judas_iscariote@shorewall.net
- HTTP_RAW_POST_DATA superglobal broken (php5-phpbug-41293.patch)
- better fix for MOPB 41.
* Sat May  5 2007 judas_iscariote@shorewall.net
- remove --enable-memory-limit configure flag, it disappeared in 5.2.1,
    nowdays memory_limit is always enabled.
* Fri May  4 2007 prusnak@suse.cz
- changed expat to libexpat-devel in Requires of devel subpackage
* Fri May  4 2007 judas_iscariote@shorewall.net
- add php5-test-fixes.patch fixing a test case that wont pass on i586
  as well a real fix for Zend/tests/bug41117_1.phpt problem, that was commited
  after the release was done. there is another test case that fails in 10.2
  ext/pcre/tests/bug40195.phpt but this is not a PHP problem but a bug in PCRE.
- added missing fix for PMOPB-45-2007 PHP ext/filter Email Validation Vulnerability (minor)
* Fri May  4 2007 judas_iscariote@shorewall.net
- php5-devel package now requires pcre-devel for > 10.1 as 5.2.2 installs
  php_pcre.h header that needs it.
* Thu May  3 2007 mmarek@suse.cz
- fixed some new compiler warnings
* Thu May  3 2007 judas_iscariote@shorewall.net
- upgrade to PHP 5.2.2, fixed hundreds of bugs including MOPB ones
  if you need the complete changes see http://www.php.net/ChangeLog-5.php#5.2.2
* Thu May  3 2007 judas_iscariote@shorewall.net
- Upgrade suhosin extension to version 0.9.19 see
  http://www.hardened-php.net/suhosin/changelog.html for details
* Fri Mar 30 2007 mmarek@suse.de
- added bison to BuildRequires, removed update-desktop-files
* Thu Mar 22 2007 mmarek@suse.de
- fixed unpack() on big-endian 64bit (revert-phpbug38770.patch)
- blacklist more env variables when safe_mode is on
  (php5-config.patch)
* Sat Mar 17 2007 judas_iscariote@shorewall.net
- fix Requires of -devel package to include only what is really
  needed for operation of the pecl tool as well the neccesary
  headers to compile php extensions.
- Fix MOPB 24 "PHP array_user_key_compare() Double DTOR
  Vulnerability"
- note that fix for MOPB 23 was included in the previous patchset.
* Wed Mar 14 2007 judas_iscariote@shorewall.net
- add security fixes for MOPB 20, 21 and 22.
- RPM_BUILD_ROOT is never defined in %%post.
* Sun Mar 11 2007 judas_iscariote@shorewall.net
- fix/workaround for php5-gd problem with typo3 [#236680]
- add fix for MOPB-14-2007 PHP substr_compare() Information Leak
  Vulnerability.
- add secfix for import_request_variables() ancient problem, users
  of suhosin extension are not affected.
- Run the test suite here
* Tue Mar  6 2007 judas_iscariote@shorewall.net
- Update suhosin extension to version 0.9.18 fixing a session
  problem.
* Mon Mar  5 2007 judas_iscariote@shorewall.net
- Update suhosin extension to version 0.9.17. see
  http://www.hardened-php.net/suhosin/changelog.html for details.
* Thu Feb 15 2007 judas_iscariote@shorewall.net
- add t1lib support in php5-gd (10.3 and up only)
- an off-by-one in str_replace may cause a crash.
* Thu Feb  8 2007 judas_iscariote@shorewall.net
- PHP 5.2.1. for a full list of changes see
  http://www.php.net/ChangeLog-5.php#5.2.1
- add Obsoletes for extensions we dont ship anymore
* Fri Feb  2 2007 judas_iscariote@shorewall.net
- fix getenv() modifing $_POST, breaks suhosin badly when
  register_* is On and variables orde is "GPCS" (default).
- change/remove obsoleted patches
* Tue Jan 30 2007 anosek@suse.cz
- synced with BuildService
  * file "session_mm_apache2handler0.sem" written at boot
    [#229200] (php5-config.patch)
  * for certain functionality php5-exif requires php5-mbstring
  * php5-ldap requires php5-openssl
  * remove LDAP_DEPRECATED from CFLAGS, module already
    takes care of this.
  * patch potential HTTP_SESSION_VARS et all hijack when
    register_globals is On users from suhosin extension are
    not affected.(php5-session-rgon-hijack.patch)
  * on 10.2 and up  php5-devel should require pcre-devel
    sqlite-devel sqlite2-devel
  * php5-devel is mostly useless without autoconf automake libtool
    bison make gcc.
  * added patches: phpbug-39350.patch
    oldhat-phpinputdata-secfix.patch
    ze2-fixes.patch
    filter.patch
    ext-lib64again.patch
* Fri Jan 26 2007 mmarek@suse.cz
- fixed string comparison in xmlrpc module (strcmp.patch)
- allways apply %%%%patch9
* Fri Jan 26 2007 mmarek@suse.cz
- updated the curl module from cvs to fix build with curl-7.16
  (curl-cvs-fix.patch, dropped gcc.patch)
* Tue Dec 19 2006 anosek@suse.cz
- fixed VUL-0: php session.save_path open_basedir bypass
  [#227569] (save_path-secfix.patch)
* Wed Dec  6 2006 anosek@suse.cz
- synced with BuildService
  * updated Suhosin patch to 0.9.6.2
  * updated Suhosin extension to 0.9.16
  * fixed php5-devel should provide PECL tool [#204006]
  * use bundled sqlite in  suse versions =< 10.1
    (pdo_sqlite stopped working properly with older sqlite3 libs)
  * do not use zend-multibyte anymore, please refer
    to phpbug #36711 and associated links, no applications uses
    this feature in the real world since it is disabled
    in all other distributions/OS.seems to cause more problems
    than solutions.
  * change php.ini, back to short_open_tag =off (the default)
    the package that depended on this setting no longer does.
    Also explicitely set the upload_tmp_dir in php.ini to deal
    with open_basedir recent changes (please refer
    to phpbug #39123) for the details.
  * suhosin.ini uses just the default recommended settings
* Wed Nov  8 2006 anosek@suse.cz
- created symlinks /usr/bin/php and /usr/bin/pear [#216166]
* Tue Nov  7 2006 mmarek@suse.cz
- fixed implicit function decls in suhosin patch (keep the original
  patch intact and put fixes into separate patch)
* Mon Nov  6 2006 mmarek@suse.cz
- updated to 5.2.0 final
- merged changes from buildservice (by soporte@onfocus.cl):
  - updated suhosin to 0.9.10
  - added suhosin patch
  - build with system PCRE if suse_release > 10.1 only [#215610]
  - suhosin extension does not require PDO
  - suhosin added to the reccommended list
  - php5-pspell to require at least aspell-en otherwise is useless
    [#217272]
* Thu Oct 26 2006 anosek@suse.cz
- php5-sqlite now uses our sqlite and sqlite2 packages to build
  and not bundled ones [#201440]
- updated suhosin to 0.9.9
* Fri Oct 20 2006 nadvornik@suse.cz
- update to 5.2.0RC6
* Thu Oct 19 2006 postadal@suse.cz
- reset right path in extension_dir (php5-php-config.patch)
* Mon Oct  9 2006 postadal@suse.cz
- update to version 5.2.0RC5
- added suhosin extension (the hardened php replacement) [#210886]
* Sun Oct  8 2006 postadal@suse.cz
- update to version 5.2.0RC4
  * added DSA key generation support to openssl_pkey_new()
  * updated PCRE to version 6.7
  * increased default memory limit to 16 megabytes to accommodate for a more
    accurate memory utilization measurement
  * added support for httpOnly flag for session extension and cookie setting
    functions
  * added version specific registry keys to allow different configurations for
    different php version
  * added "PHPINIDir" Apache directive to apache and apache_hooks SAPIs
  * added an optional boolean parameter to memory_get_usage() and
    memory_get_peak_usage() to get memory size allocated by emalloc() or real
    size of memory allocated from system
  * moved extensions to PECL (filepro and hwapi)
  * improved SNMP, OpenSSL extension
  * improved the Zend memory manager, FastCGI SAPI, CURL, PCRE, PDO, SPL,
    xmlReader
- merged changes from openSUSE build service
  * build without --enable-sigchild [#206533, php#28294, php#38342]
  * build CLI with libedit support (really-with-libedit.patch)
  * tweaked the default config a bit, to make it more secure
  * removed ini entries related to extensions we don't ship
  * t1lib is not currently needed for build, we need t1lib5 to do
    something useful
  * removeed --enable-ucd-snmp-hack (needed for ucd-snmp, but we use net-snmp)
  * pdo_odbc provided by php-odbc
  * php-suse-addons :
    o PHP5 is unlikely to parse php3 code, remove the file association
    o corrected apache directive is AddHandler not AddType
  * dropped extensions:
    o mysql, mysqli and pdo_mysql provided by php-mysql (reduce package count)
    o php-pdo_sqlite provided by php-sqlite
    o php-pdo_pgsql provided by php-pgsql
    o filepro dropped by upstream
  * new extension:
    o filter (kept static and cannot be unloaded, due security reasons)
    o json (added as Recommended)
    o zip (it uses a bundled library)
- fixed gcc issues (gcc.patch)
- droped obsoleted patches: include_path.patch, bug-37720.patch,
  bug-37306.patch, cgi_bugs.patch, bug-37587.patch, gd-fixes.patch,
  bug-37416.patch, main_bugs.patch, soap.patch, standard.patch,
  mbstring_bugs.patch, ze2_bugs.patch, xsl_bugs.patch, curl.patch
* Wed Aug 16 2006 postadal@suse.cz
- fixed build with X11R7
* Wed Jul 26 2006 postadal@suse.cz
- updated to version 5.1.4
  * FastCGI interface was completely reimplemented
  * multitude of improvements to the SPL, SimpleXML, GD, CURL and
    Reflection extensions
  * support for many additional date formats added to the strtotime()
  * a performance improvements added to the engine and core extensions
  * added imap_savebody() that allows message body to be written to a file
  * added lchown() and lchgrp() to change user/group ownership of symlinks
  * upgraded bundled PCRE library to version 6.6
- merged changes from openSUSE build service
  * removed unneeded sablot-devel,sqlite-devel,pcre-devel,fam-devel
    and libmcal from BuildRequires
  * added php-ctype,php-dom,php-iconv,php-pdo,php-pdo_sqlite,php-sqlite,
    php-tokenizer,php-xmlreader,php-xmlwriter to Recommends
  * added php-mbstring php-gd php-pear php-gettext php-mysqli to Suggests
  * added support for optional readline(libedit) for CLI
    (disabled by default)
  * patches for zendengine (ze2_bugs.patch), xsl (xsl_bugs.patch),
    curl (curl.patch) and mbstring bugs (mbstring_bugs.patch),
    big soap patch (soap.patch)
  * removed obsoleted patches
  * fixed Safe Mode Bypass [#188243] (standard.patch)
  * upstream patches
    [php#37306, php#37416, php#37587, php#37720]
    [php#37576, php#37496, php#37341, php#37313, php#37256] (cgi_bugs.patch)
    [php#37346, php#37360] (gd-fixes.patch)
  * fixed build inconsistences, added php-hash module [#173023]
  * added pdo_odbc.so to php-odbc module [#190614]
  * build without explicit safe_mode and magic_quotes (unneeded)
  * removed useless GD --with-ttf configure option, only suitable
    for freetype 1
* Fri Jun  9 2006 poeml@suse.de
- fix BuildRequires to build on SUSE Linux 10.1, 10.0, 9.3
- use the -fstack-protector compile switch only on 10.0 and newer
* Thu May 11 2006 postadal@suse.cz
- fixed memory leak in imagecreatefromgif()
  [#173451] (phpbug-37346.patch)
- fixed possibility of a wrong element being deleted by zend_hash_del()
  [#175976] (zend_hash_del.patch)
- fixed substr_compare() when offset equals string length
  [#169038, php#37394] (CVE-2006-1991, phpbug-37394.patch)
- fixed _emalloc() on 64bit archs [#169038] (emalloc.patch)
* Wed May  3 2006 postadal@suse.cz
- fixed completely broken SplTempFileObject [php#37257]
  (phpbug-37257.patch)
- fixed problem with with $_POST array [php#37276]
  (phpbug-37276.patch)
* Wed Apr 12 2006 postadal@suse.cz
- fixed security problem in copy() and tempname()
  [#164845] (CVE-2006-1494-1608.patch)
- fixed phpinfo() XSS [#164804] (CVE-2006-0996.patch)
- fixed memory leak in html_entity_decode  [#161718] (CVE-2006-1490.patch)
- fixed multiple imap safemode and open_basedir restriction bypass
  [#154317] (CVE-2006-1017.patch)
* Mon Mar 27 2006 postadal@suse.cz
- fixed buffer overrun in ftp_fopen_wrapper (ftp_fopen_wrapper.patch)
* Tue Mar 14 2006 postadal@suse.cz
- added updating APACHE_MODULES in /etc/sysconfig/apache2 [#155333]
- added forgotten regenerated sources for (parse_date.patch and
  phpbug-36459.patch)
- fixed upstream bugs:
    [php#36420] (phpbug-36420)
  - segfault when access result->num_rows after calling result->close()
    (mysqli-64bit.patch)
  - fixed a 64-bit problem
* Fri Mar  3 2006 postadal@suse.cz
- fixed a possible null injection in mbstring (mbstring-null_injection.patch)
- fixed upstream bugs:
    [mysql#16144] (phpbug-16144)
  - fix for MySQL 5.1 (mysql_stmt_attr_get)
    [php#36656] (phpbug-36656)
  - http_build_query generates invalid URIs due to use of square brackets
    [php#36396,36510,36510,36638] (parse_date.patch)
  - fixed few bugs in date/time parsing
    (string.patch)
  - added overflow checks to wordwrap() function
    [php#36459] (phpbug-36459)
  - incorrect adding PHPSESSID to links, which contains \r\n
* Fri Mar  3 2006 postadal@suse.cz
- added php5-openssl to php5-ftp Requires [#154273]
- added safe_mode num of parameter check for mb_send_mail [#154315]
* Fri Feb 10 2006 postadal@suse.cz
- fixed upstream bugs:
  [php#36306] (phpbug-36306.patch)
  - fixed crc32() for 64bit arch
  [php#36351] (phpbug-36351.patch)
  - parse_url() did not parse numeric paths properly
  (spl_directory.patch)
  [php#35998]
  - getPathname() method always returns unix style filenames
  [php#36134]
  - DirectoryIterator constructor failed to detect empty directory names
  [php#36258]
  - SplFileObject::getPath() may lead to segfault
  [php#36287]
  [php#36295]
  [php#36359]
  - splFileObject::fwrite() doesn't write when no data length specified
  (session2.patch)
  - fixed logic, if the client already sent us the cookie, we don't
    need to send it again
  (soap.patch) [php#36226, php#36083, php#36283]
  (math.patch, simplexml.patch, mbstring.patch, zend_operators.patch, xp_socket.patch)
  - initialize variables
* Sat Feb  4 2006 postadal@suse.cz
- removed gd-devel from BuildRequires (better used bundled modified gd lib)
- fixed upstream bugs:
  [php#36268] (phpbug-36268.patch)
  [php#36148] (phpbug-36148.patch)
  [php#36185] (phpbug-36185.patch)
  [php#36208] (phpbug-36208.patch)
  [php#36158] (phpbug-36158.patch)
* Tue Jan 31 2006 postadal@suse.cz
- reverted default value for short_open_tag to On [#145895]
* Mon Jan 30 2006 postadal@suse.cz
-  fixed upstream bugs:
  [php#36176] (phpbug-36176.patch)
  (pdo.patch)
  - properly rewrite queries where a bound parameter appears more then once
* Mon Jan 30 2006 poeml@suse.de
- removed libapr-util1-devel from BuildRequires (apache2-devel does
  require it)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 postadal@suse.cz
- added php5-pdo to requires for pdo_mysql, pdo_pgsql, pdo_sqlite and
  sqlite and php5-dom to requires for xmlreader and xsl [#144360]
- revert name of extensions (appended suffix .so) [#143552]
- removed _FILE_OFFSET_BITS=64 and _LARGEFILE_SOURCE from CFLAGS
  (doesn't work with apache2 configuration, which uses libapr with
  native support for large files) [#144362]
- added -fstack-protector
* Mon Jan 23 2006 postadal@suse.cz
- added forgoted extension xmlwrite
- gave back simple dot to include_path [#129682]
- fixed upstream bugs:
  [php#36071] (phpbug-36011.patch)
  [php#36016] (phpbug-36016.patch)
  - realpath cache memleaks
  [php#36071] (phpbug-36071.patch)
  - Zend engine crash related with 'clone'
  (zend-fix.patch)
  - fix issues with static method invocation
  - ce_child is properly initialized
  [php#36046] (phpbug-36046.patch)
  - parse_ini_file() miscounts lines in multi-line values
  [php#36037] (phpbug-36037.patch)
  - heredoc adds extra line number
  [php#36006] (phpbug-36006.patch)
  - problem with $this in __destruct()
  (gd.patch)
  - improve open_basedir checks in GD
  [php#36007] (phpbug-36007.patch)
  - added new mysqli constants for BIT and NEW_DECIMAL field types (for mysql 5)
  (session.patch)
  - check for special characters in the session name
  (xmlreader.patch)
  - 64bit fixes
* Thu Jan 19 2006 postadal@suse.cz
- disable discard-path for fastcgi binary [#143564]
* Wed Jan 18 2006 postadal@suse.cz
- updated to version 5.1.2
- removed obsoleted patches: CAN-2005-1042_1043.patch, CVE-2005-3353.patch,
  openssl.patch, soap.patch, pdo.patch, simplexml.patch, curl.patch,
  ze.patch
- added pdo, pdo_mysql, pdo_pgsql, pdo_sqlite extensions
* Tue Jan 17 2006 mrueckert@suse.de
- remove apache2-mod_fastcgi from nfb it seems to be unused
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Tue Jan 10 2006 ro@suse.de
- avoid rpath /usr/ssl/lib in curl ext
* Wed Jan  4 2006 postadal@suse.cz
- updated to version 5.1.1 [#135635, #139297]
- removed obsoleted patches: php5-with_lib.patch, soap.patch, posix.patch,
  gcc4.patch, save_path-segfault.patch, basedir-fix.patch,
  RPC-CAN-2005-1921.patch, RPC-CAN-2005-2498.patch, pcre-overflow-bug-106209.patch,
  CVE-2005-3388.patch, CVE-2005-3389.patch, CVE-2005-3390.patch,
  mod_rewrite-fix.patch, mbstring.patch, CVE-2005-3391.patch, CVE-2005-3392.patch,
  errordocument-fix.patch
- removed sqlite2 from build dependencies and added libtidy libtidy-devel
- removed dbx, fam, yp, dio extensions (upstream deprecated)
- added dba, tidy and xmlreader extensions
- renamed libphp5.so -> mod_php5.so (need it for yast module)
- added upstream patches:
  openssl.patch [php#35381]
  soap.patch [php#35399]
  pdo.patch [php#35431, php#35430]
  simplexml.patch [php#35028]
  curl.patch [php#35908]
  ze.patch [php#35393]
- updated pear sources install-pear-nozlib.phar
- package CLI instad CGI binaries [#137443]
- reverted last changes (problem caused curl-devel package)
* Thu Dec 15 2005 mmarek@suse.cz
- provide php-pear in php5-pear
- add /usr/share/php5/PEAR to include path
* Tue Dec  6 2005 postadal@suse.cz
- fixed [php#33987] bug (php script as ErrorDocument causes crash
  in Apache 2).
* Mon Dec  5 2005 postadal@suse.cz
- fixed unexpected header can be injected to mb_send_mail()
  [#135673] (mbstring.patch)
- added safe_mode checks for image* functions and cURL
  [#135673] (CVE-2005-3391.patch)
- fixed possible INI setting leak via virtual() in Apache 2 sapi
  [#135673] (CVE-2005-3392.patch)
* Tue Nov 29 2005 mmarek@suse.cz
- build with flex-old until upstream fixes build with flex-2.5.31
* Mon Nov 28 2005 postadal@suse.cz
- fixed CVE-2005-3388.patch [#131578]
* Fri Nov 25 2005 postadal@suse.cz
- fixed segfaulting with mod_rewrite [#135480] (mod_rewrite-fix.patch)
* Tue Nov 22 2005 uli@suse.de
- define ARM FP(A) endianness correctly
* Tue Nov 15 2005 mmarek@suse.cz
- fixed infinite recursion in exif code
  [#132684] (CVE-2005-3353.patch)
- fixed XSS in phpinfo()
  [#131578] (CVE-2005-3388.patch)
- fixed register_globals actvation in parse_str()
  [#131579] (CVE-2005-3389.patch)
- fixed possible $GLOBALS overwrite
  [#131580] (CVE-2005-3390.patch)
- fixed handling basedirs that end with a /
  [#118976] (basedir-fix.patch)
- fixed segfaulting when save_path is set and safe_mode is On
  [#130227] (save_path-segfault.patch)
* Tue Oct 25 2005 rhafer@suse.de
- added LDAP_DEPRECATED to CFLAGS to build correctly with
  OpenLDAP 2.3
* Fri Oct 14 2005 postadal@suse.cz
- fixed recode extension [#120087] (recode-fix.patch)
- enabled _GNU_SOURCE for compiling
* Wed Oct 12 2005 postadal@suse.cz
- fixed implicit declaration (gcc4.patch)
* Mon Oct 10 2005 postadal@suse.cz
- fixed uninitialized variables (gcc4.patch)
* Thu Sep  1 2005 postadal@suse.cz
- added security patch pcre-overflow-bug-106209.patch for internal
  libpcre and statically linked against it [#114157]
- added include_path = "/usr/share/php" to php.ini [#114406]
* Thu Aug 25 2005 postadal@suse.cz
- linked with system pcre libs (pcre-fix.patch) [#112645]
* Thu Aug 18 2005 postadal@suse.cz
- fixed XML RPC command injection
  (#94579, CAN-2005-192 and #104403, CAN-2005-2498)
* Tue Aug  9 2005 mls@suse.de
- removed compat from neededforbuild
* Tue Aug  2 2005 tcrhak@suse.cz
- dropped php4-dba and php4-readline due to license problems (bug #91489)
- compile without -DPHP_AP_DEBUG (bug #95502)
- fixed php-config to return a correct includes path (patch php5-php-config)
- fixed a sigsegv in the soap extension (bug #99268, patch php5-soap)
* Mon Apr 25 2005 mcihar@suse.cz
- added pspell subpackages
* Tue Apr 19 2005 mcihar@suse.de
- update tarball to rereleased one which contains missing file
* Sat Apr  9 2005 aj@suse.de
- Compile with GCC4.
* Mon Apr  4 2005 mcihar@suse.cz
- update to 5.0.4
- drop patches merged upstream
- add RunTests.php missing from upstream tarball
* Thu Mar 17 2005 mcihar@suse.cz
- fix path to configuration files
* Mon Mar 14 2005 mcihar@suse.cz
- do not build CLI with all GCI stuff
- fix build when extensions are built as *.so instead of just *
- use different php.ini for each SAPI, this is needed for giving CLI more space to live (bug #72311)
* Wed Mar  9 2005 mcihar@suse.cz
- provide compiled in modules
* Mon Mar  7 2005 mcihar@suse.cz
- fix path to php5 binary in pear5 script (bug #71044)
* Thu Mar  3 2005 mcihar@suse.de
- realy enable xml module
* Tue Mar  1 2005 mcihar@suse.cz
- provide only mod_php_any in apache module (bug #66729)
* Mon Feb 21 2005 mcihar@suse.cz
- fix some compile time warnings
* Thu Feb 10 2005 mcihar@suse.cz
- add zlib dependency to pear (bug #50697)
* Wed Feb  9 2005 mcihar@suse.cz
- use correct path to apache2_MMN
- comment some patches
- update README.SUSE
- drop unused sce_install
- each extension now provides also unversioned symbol, to allow not to depend
  on specific php version
- drop MIME type change as both php modules don't work together anyway
* Tue Feb  8 2005 mcihar@suse.cz
- drop actually unused patches
- fix build on ia64 (endians patch, stolen from cvs) (still doesn't build due to missing current MySQL)
- fix build on lib64 machines
* Mon Feb  7 2005 mcihar@suse.cz
- initial packaging of php5
- suse addons are now in tarball instead of patch
- reorganize patches
- simplified build system
* Wed Jan 26 2005 mcihar@suse.cz
- update asp2php
- drop lynx from buildrequires
* Tue Jan 11 2005 mcihar@suse.cz
- fix broken int unserializing on 64-bit (bug #49617)
* Fri Dec 17 2004 poeml@suse.de
- update to 4.3.10
- for apache module, pick up CFLAGS from apxs [#49356]
- drop obsolete php-4.3.9RC3.diff
- update lib64.diff
- fix return type in php_sprintf()
- don't apply php-4.3.8-snmp.diff
- do not clean buildroot in buildsystem to facilitate debugging
- fix PreRequires (sce_install_path) [#46664]
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Thu Nov  4 2004 ro@suse.de
- added rpm-devel,popt-devel,tcpd,tcpd-devel to neededforbuild (for snmp)
* Tue Oct  5 2004 pmladek@suse.cz
- added /usr/lib/php/sce_install to prerequires of php4-swf; it is in the
  package php4-32bit on x86_64 [#46475]
* Thu Sep 23 2004 tcrhak@suse.cz
- security fix for array parsing (bug #45710) and
  some other fixes from php-4.3.9RC3 (patch 4.3.9RC3)
- removed the #%%endif causing syntax error during /usr/lib/php/sce_install (bug #45589)
- /var/lib/php is now owned by wwwrun (bug #45360)
- reverted dlopen flag back to RTLD_GLOBAL (bugs #39197 and #41866),
  php4-recode now conflicts with php4-imap, php4-mysql and apache2-mod_auth_mysql,
  mod_php4-core does not require php4-recode any more
- dropped php4-dba and php4-readline due to license poblems (bug #45654)
* Fri Sep 17 2004 tcrhak@suse.cz
- added tomcat5 to the Requires of php4-servlet
* Wed Sep 15 2004 tcrhak@suse.cz
- removed the build dependency on tomcat5
- added tomcat5 directories to filelist
- enabled iconv for the other archs
* Tue Sep 14 2004 skh@suse.de
- use new JPackage packages tomcat5 and servletapi5 to build
* Fri Sep 10 2004 tcrhak@suse.cz
- do not source setJava
* Fri Sep  3 2004 tcrhak@suse.cz
- update to 4.3.8
- added module dbx (bug #43972)
- use system gd library, includes "GIF Create Support" (bug #44001)
- disallow persistant connections by default (bug #34849)
- use /var/lib/php for php sessions by default (bug #36886)
- php modules need to prereq sce_install (bug #43994)
* Thu Aug 19 2004 aj@suse.de
- Remove broken cat commands from post section:
  * no requires for them
  * no need to execute them
* Mon Aug 16 2004 ro@suse.de
- fix build with updated libcurl: use current instead of
  deprecated type for curl_httppost
* Tue Jun  8 2004 ro@suse.de
- removed mod_dav from neededforbuild
- removed mod_php4 package (mod_php4-core is probably obsolete too)
* Tue May  4 2004 tcrhak@suse.cz
- build with postfix instead of sendmail
* Thu Apr 29 2004 ro@suse.de
- remove apache1 related parts
* Fri Apr 23 2004 tcrhak@suse.cz
- added sendmail to neededforbuild, so that mail() is defined (bug #39153)
- dlopen php modules with RTLD_LOCAL (fixes bug #39197)
* Wed Mar 31 2004 tcrhak@suse.cz
- added php module recode (bug #36573)
- fixed requires of mod_php4-apache2 (bug #37041)
* Mon Mar 22 2004 ro@suse.de
- build-fix for jakarta-tomcat from skh
- removed apache-contrib from neededforbuild (dropped)
* Tue Mar 16 2004 tcrhak@suse.cz
- removed --enable-versioning (fixes bug #35716)
- do not build servlet for ia64, ppc and ppc64
* Fri Mar  5 2004 tcrhak@suse.cz
- modularized
- updated to version 4.3.4
- added fastcgi
- added PHP4 module sockets
- added PHP4 module mime_magic (bug #34134)
- php binary is now CLI, not CGI (bug #34152)
* Wed Feb 18 2004 ro@suse.de
- use jakarta-tomcat4
* Mon Feb 16 2004 ro@suse.de
- use unixODBC instead of iodbc
* Tue Feb 10 2004 poeml@suse.de
- fix symbol exports for apache2
- add -fno-strict-aliasing to CFLAGS, due to code where
  dereferencing type-punned pointers would break strict aliasing
- fix test load of apache2 module (the LoadModule statement went
  into the wrong place)
* Sun Feb  8 2004 schwab@suse.de
- Fix symbol exports.
- Also look for BEAJava2 directory.
- Fix quoting.
* Thu Jan 22 2004 ro@suse.de
- fix build with current automake
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Tue Jan 13 2004 ro@suse.de
- remove subpackage aolserver
- fix build with current freetype
* Mon Nov 10 2003 ro@suse.de
- use net-snmp instead of ucdsnmp
* Thu Oct 30 2003 tcrhak@suse.cz
- ad previous fix: create the directory
* Wed Oct 29 2003 tcrhak@suse.cz
- added %%{_libdir}/php/bin to file list of mod_php4-core
* Mon Sep 22 2003 mls@suse.de
- remove 'Obsoletes: mod_php' from mod_php4, otherwise rpmv4
  makes mod_php4 conflict with apache2-mod_php4
* Tue Sep 16 2003 tcrhak@suse.cz
- update to version 4.3.3
* Mon Sep  1 2003 tcrhak@suse.cz
- expand rpm macros in /etc/httpd/modules/mod_php4 [bug #29664]
* Thu Aug 21 2003 tcrhak@suse.cz
- update to version 4.3.2
- use BuildRoot
- added activation metadata to sysconfig [bug #28827]
* Mon Aug 18 2003 poeml@suse.de
- add README.{SuSE,UnitedLinux} [#25888]
- don't explicitely strip binary objects, because RPM does it
  anyway, and it might keep the stripped debugging info somewhere.
- don't try to install a file in /etc/apache2/modules/ (it's gone)
* Mon Jun 30 2003 ro@suse.de
- always use libtool to compile objects
- added directories to filelist
* Thu Apr 10 2003 tcrhak@suse.cz
- use 'head -n 1' instead of 'head -1'
- added mhash support
* Wed Mar 26 2003 tcrhak@suse.cz
- fixed path in script phpize
- fixed ext/mysql/config.m4
* Thu Mar 13 2003 tcrhak@suse.cz
- fixed order of Type and Define in sysconfig metadata
- readded subpackage servlet (patch servlet)
- reenabled support for swf
- install swf fonts, use proper SWFFONTPATH
  (bug #18057, patch swf)
* Tue Mar  4 2003 poeml@suse.de
- the apache2 module requires the apache2-prefork MPM
* Thu Feb 20 2003 tcrhak@suse.cz
- security update to version 4.3.1 - fixes a CGI vulnerability
- added sysconfig metadata [bug #22604]
* Fri Feb 14 2003 tcrhak@suse.cz
- added php3, php4 to DirectoryIndex [bug #22066]
* Thu Feb 13 2003 ro@suse.de
- really disable (empty) subpackage servlet
* Wed Feb 12 2003 poeml@suse.de
- rename subpackage mod_php4_2 to apache2-mod_php4
* Tue Feb 11 2003 poeml@suse.de
- call the new /usr/share/apache2/get_module_list script to
  configure apache2, so the test can be passed
* Wed Jan 15 2003 ro@suse.de
- use sasl2
* Fri Jan 10 2003 poeml@suse.de
- don't built -servlet for now, needs work
- swf.h has vanished from ./dist/include/, and I can't find another
  one --> disabling swf support
* Thu Jan  9 2003 poeml@suse.de
- update to 4.3.0
  - GD library is now bundled with the distribution and it is
    recommended to always use the bundled version
  - vpopmail and cybermut extensions are moved to PECL
  - several deprecated extensions (aspell, ccvs, cybercash, icap)
    and SAPIs (fastcgi, fhttpd) are removed
  - speed improvements in a variety of string functions
  - Apache2 filter is improved, but is still considered
    experimental (use with PHP in prefork and not worker (thread)
    model since many extensions based on external libraries are not
    thread safe)
  - various security fixes (imap, mysql, mcrypt, file upload, gd, etc)
  - new SAPI for embedding PHP in other applications (experimental)
  - much better test suite
  - significant improvements in dba, gd, pcntl, sybase, and xslt
    extensions
  - debug_backtrace() should help with debugging
  - error messages now contain URLs linking to pages describing the
    error or function in question
  - Zend Engine has some fixes and minor performance enhancements
  - and TONS of other fixes, updates, new functions, etc
- build apache2 module
- QtDOM support is now in qt3, and therefore we need to link
  against libqt-mt
- merge the lib64 patch, hope it's complete
- gd lib is now bundled, and preferred for building
- adjust the Provides of the -core package
* Thu Nov 21 2002 ro@suse.de
- make it build with current automake
* Wed Oct 16 2002 tcrhak@suse.cz
- added support for readline
- added support for iconv and mbstrings [bugs #19861 and #19862]
* Fri Sep 27 2002 tcrhak@suse.cz
- added type .php3 to apache mod_php4.conf
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Sep  3 2002 tcrhak@suse.cz
- fixed to build on 64 bit archs
* Fri Aug 23 2002 tcrhak@suse.cz
- fixed to build on non-i386 archs
- added dynamic extensions to the file list of subpackage core
* Tue Aug 20 2002 tcrhak@suse.cz
- added PreReq
* Tue Aug 13 2002 kukuk@suse.de
- Remove unused qt2 from neededforbuild
* Wed Aug  7 2002 uli@suse.de
- fixed to build on lib64 archs (still broken on nearly all archs
  due to other problems)
* Mon Aug  5 2002 ro@suse.de
- use "-follow" when searching for jni.h
* Sun Jul 28 2002 kukuk@suse.de
- remove unused gdb from neededforbuild
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul 26 2002 kukuk@suse.de
- Add imap-lib to neededforbuild
* Tue Jul 23 2002 tcrhak@suse.cz
- update to version 4.2.2
- update of asp2php to version 0.76.12
- detect the module magic number if provided by apache, indicating
  API changes, and add an RPM Require on it
- add compiled extensions (currently gd.so, as it is build shared
  by a previous change by bk@suse.de) to php.ini and filelist
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue May 28 2002 ro@suse.de
- replaced /opt/jakarta with /opt/jakarta/tomcat
* Mon May 27 2002 ro@suse.de
- first try for lib64
* Mon May 27 2002 bk@suse.de
- use shared libgd on all archs
* Sat Mar 23 2002 ro@suse.de
- removed unixODBC stuff, was never used (iodbc is used)
* Fri Mar 15 2002 tcrhak@suse.cz
- added %%{_datadir}/lib/php and extension dir to devel filelist
* Mon Mar  4 2002 okir@suse.de
- security fix
* Fri Feb 22 2002 tcrhak@suse.cz
- Killed %%{release} from "Requires" tags.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 ro@suse.de
- added des to neededforbuild
* Mon Jan 28 2002 ro@suse.de
- added heimdal stuff to build
* Wed Jan 23 2002 ro@suse.de
- try to build with db-devel in neededforbuild
* Thu Jan 17 2002 ro@suse.de
- adapted for /etc/sysconfig/apache
* Thu Dec 20 2001 tcrhak@suse.cz
- update to 4.1.0
- no mm support for aol and servlet (mm is not ZTS in 4.1 yet)
- patched acinclude.m4 to find the very dir for mysql libraries
- added `php-config --extension-dir` to core files
* Mon Dec 10 2001 tcrhak@suse.cz
- fixed extension section
* Thu Dec  6 2001 tcrhak@suse.cz
- added section [extension section] to php.ini
- fixed options given to configure
* Tue Dec  4 2001 tcrhak@suse.cz
- fixed configure.in and config.m4's for autoconf 2.52
- added libtoolize, autoconf, autoheader
- used setJava to find JAVA_HOME
- TTF - bug 9523
- gd  - bug 12226
- changed the order in which subpackages (for Servers) are built,
- so that the devel package corresponds to core
- (=> experimental-zts disabled)
- moved phpize to the devel package (fixed for autoconf 2.52)
- added files needed by phpize to the devel package
* Mon Dec  3 2001 ro@suse.de
- changed servlet dir for configure with jakarta
* Mon Dec  3 2001 ro@suse.de
- fixed neededforbuild <jakarta> to <jakarta-tomcat>
* Tue Nov 20 2001 rolf@suse.de
- changes to make IA64 work
- exclude subpackages AOL and Servlet from AXP
* Sun Nov 18 2001 ro@suse.de
- fix to find java
* Wed Nov 14 2001 rolf@suse.de
- new subpackage -devel with include files
* Mon Nov 12 2001 ro@suse.de
- hack for libxml2 include location
* Thu Oct 25 2001 ro@suse.de
- use qt2 for qtdom (but aparently that is not built anyway)
* Wed Oct 24 2001 ro@suse.de
- try neededforbuild alias apache-devel-packages
* Mon Sep 10 2001 ro@suse.de
- remove roxen subpackage
  roxen is not in the distribution currently
* Wed Aug 22 2001 ro@suse.de
- removed pdflib from neededforbuild (license problems)
* Tue Aug 14 2001 ro@suse.de
- pear: changed header to look for php in "bindir" not "prefix/bin"
  to fix requires
* Mon Aug 13 2001 kukuk@suse.de
- Don't conflict with packages we are providing
* Thu Aug  9 2001 kukuk@suse.de
- Fix search for installed java directory
* Tue Jul 24 2001 rolf@suse.de
- new subpackage mod_php4-aolserver for use of PHP4 with AOL server
- disable-debug so Zend optimizer can work
* Thu Jul  5 2001 rolf@suse.de
- update to php 4.0.6
- apply memlimit patch
- new subpackage mod_php4-servlet for use of PHP4 as JAVA servlet
  with tomcat
- new options: --with-gmp, --with-dom, mbstring
* Mon Jun 25 2001 rolf@suse.de
- fixed bug with pdflib which also fixes [BUG#8246]
* Tue Jun 19 2001 rolf@suse.de
- new version 4.0.5
- disable pgsql for roxen, as it is broken
- mysql bug fixed in this release [BUG#6839]
- move stuff to /usr/share/php [BUG#8352]
- now Provides: mod_php as well [BUG#8911]
* Sat May 12 2001 schwab@suse.de
- Use new readline interface.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue May  1 2001 kukuk@suse.de
- disable adabas support
* Thu Apr 26 2001 ro@suse.de
- neededforbuild: curl_ssl-devel -> curl-devel
* Sun Apr  8 2001 poeml@suse.de
- fix Requires (rearrange tags to define them before using them)
- fix spec file typo
* Tue Mar 27 2001 rolf@suse.de
- spin off subpackage mod_php4-core which is required by apache and
  roxen modules now
- moved config file to /etc/php.ini for all php4 modules
- sybase support conflicts with Adabas D support
- Ingres support is for Ingres II only
- added t1lib support [BUG#6212]
- updated asp2php 0.75.13
- make us of suse_loadmodule for testing
- added /usr/bin/php to core package [BUG#6648]
* Wed Mar 21 2001 ro@suse.de
- changed neededforbuild to freetype2
* Thu Mar 15 2001 ro@suse.de
- build with openldap2
* Thu Mar 15 2001 ro@suse.de
- fixed neededforbuild for openldap
* Mon Mar  5 2001 ro@suse.de
- use -fPIC
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Thu Feb 15 2001 rolf@suse.de
- new features imap-ssl, bz2, qtdom, ctype, debug, force-cgi-redirect,
  discard_path, sigchild, gd-imgstrttf
- added apache-mod_php4.rc.config
- added /etc/httpd/modules/mod_php4
* Wed Jan 17 2001 rolf@suse.de
- add libpdf support
* Tue Jan 16 2001 rolf@suse.de
- update to 4.0.4pl1 due to security issue [BUG#5760]
- remove number4.tar.gz, no longer needed
* Fri Jan 12 2001 rolf@suse.de
- need expat to compile [BUG#5104]
- subpackage for roxen module
* Fri Jan 12 2001 cihlar@suse.cz
- fixed to compile with roxe/pike [#4408]
* Tue Dec 19 2000 rolf@suse.de
- link with libssl
* Tue Dec 19 2000 rolf@suse.de
- added the asp2php package [BUG#4456]
- roxen/pike still doesn´t work
- require RPM group tag via apxs
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <pg_lib> to <postgresql-lib>
* Mon Nov 27 2000 rolf@suse.de
- added Sablotron support     [BUG#3891]
- added curl support          [BUG#3890]
- added Flash support on i386 [BUG#3209]
- also pack module files in /usr/lib/php/
- moved the exec dir to /usr/lib/php/bin
- include pear binaries
- added the following modules: sockets, shmop, exif, filepro, dbase
  readline, mcrypt, gettext
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild gdlib -> gd gd-devel
* Wed Nov  8 2000 ro@suse.de
- prefer ndbm.h to db1/ndbm.h
* Mon Nov  6 2000 ro@suse.de
- added imap-devel to neededforbuild
* Mon Nov  6 2000 ro@suse.de
- fixed neededforbuild
* Mon Oct 16 2000 bk@suse.de
- s390: --with-gd=yes -> --with-gd=shared(broken somehow with =yes)
* Mon Oct 16 2000 rolf@suse.de
- update tp 4.0.3pl1 due to some security breaches
- needed to drop db3 and dbm support, as these are incompatible
- enable FTP support [BUG#3862]
* Wed Sep 13 2000 fober@suse.de
- s390: suse_update_config, needs-not-forbuild adabas
* Fri Jul  7 2000 kukuk@suse.de
- Fix Requires and need for build
* Fri Jun 23 2000 rolf@suse.de
- added support for mcal and calendar functions [BUG#2925]
* Sun Jun 18 2000 ro@suse.de
- fixed to compile with new postgres
* Mon May 22 2000 rolf@suse.de
- update to 4.0.0
- --with-java is now broken
* Fri May 12 2000 rolf@suse.de
- update to 4.0RC2
- a few more options are now functional
* Thu Apr 13 2000 ro@suse.de
- added mm to neededforbuild
* Thu Mar 30 2000 rolf@suse.de
- new version 4.0RC1
- many options now work properly
* Wed Mar  1 2000 rolf@suse.de
- zlib works again
* Tue Feb 22 2000 rolf@suse.de
- new version 4b4pl1
- now with --enable-thread-safety --with-gd=yes --with-ttf
- imap support is now broken
* Thu Dec 23 1999 rolf@suse.de
- dynamic JDK path detection
- some fixes in DAV, still doesn´t work
- now also runs with IMAP
* Thu Nov 25 1999 rolf@suse.de
- initial package version 4.0b3
